@@ -2,13 +2,16 @@
 #VERSION=$(head -1 debian/changelog | sed 's/.*(\(.*\)).*/\1/')
 VERSION=$(grep -m 1 APPVERSION variables.pri | cut -d '=' -f 2 | sed -e 's/^[[:space:]]*//' | tr ' ' _ | tr -d '\r\n')
 
-# Compile translations
-./translate.sh
-
 # Build
 if [ -n "$QTDIR" ]; then
     $QTDIR/bin/qmake $1
     make distclean
+    # Compile translations
+    if [[ $1 == *"qmlui"* ]]; then
+        ./translate.sh "qmlui"
+    else
+        ./translate.sh "ui"
+    fi
     $QTDIR/bin/qmake $1
 else
     qmake -spec macx-g++
@@ -16,7 +19,12 @@ else
     qmake -spec macx-g++
 fi
 
-make -j4
+NUM_CPUS=`sysctl -n hw.ncpu` || true
+if [ -z "$NUM_CPUS" ]; then
+    NUM_CPUS=4
+fi
+
+make -j$NUM_CPUS
 
 if [ ! $? -eq 0 ]; then
     echo Compiler error. Aborting package creation.
