@@ -49,6 +49,9 @@ void AudioRenderer::adjustIntensity(qreal fraction)
 
 void AudioRenderer::setFadeIn(uint fadeTime)
 {
+    m_fadeStep = 0;
+    m_currentIntensity = 1.0;
+
     if (fadeTime == 0 || m_adec == NULL)
         return;
 
@@ -86,8 +89,10 @@ void AudioRenderer::stop()
 
 void AudioRenderer::run()
 {
+    qint64 audioDataWritten;
     m_userStop = false;
     audioDataRead = 0;
+
     int sampleSize = m_adec->audioParameters().sampleSize();
     if (sampleSize > 2)
         sampleSize = 2;
@@ -95,7 +100,7 @@ void AudioRenderer::run()
     while (!m_userStop)
     {
         QMutexLocker locker(&m_mutex);
-        qint64 audioDataWritten = 0;
+        audioDataWritten = 0;
         if (m_pause == false)
         {
             //qDebug() << "Pending audio bytes: " << pendingAudioBytes;
@@ -175,7 +180,7 @@ void AudioRenderer::run()
                 if (audioDataWritten == 0)
                     usleep(15000);
             }
-            //qDebug() << "[Cycle] read: " << audioDataRead << ", written: " << audioDataWritten;
+            //qDebug() << "[Cycle] read:" << audioDataRead << ", written:" << audioDataWritten << ", pending:" << pendingAudioBytes;
         }
         else
         {
