@@ -605,6 +605,16 @@ int ChaserRunner::getNextStepIndex()
         m_chaser->direction() == Function::Backward)
             currentStepIndex = m_chaser->stepsCount();
 
+    // Handle reverse Ping Pong at boundaries
+    if (m_chaser->runOrder() == Function::PingPong &&
+        m_pendingAction.m_action == ChaserPreviousStep)
+    {
+        if (currentStepIndex == 0)
+            m_direction = Function::Backward;
+        else if (currentStepIndex == m_chaser->stepsCount() - 1)
+            m_direction = Function::Forward;
+    }
+
     // Next step
     if (m_direction == Function::Forward)
     {
@@ -773,8 +783,8 @@ bool ChaserRunner::write(MasterTimer *timer, QList<Universe *> universes)
 
             m_lastFunctionID = step->m_function->type() == Function::SceneType ? step->m_function->id() : Function::invalidId();
             step->m_function->stop(functionParent(), m_chaser->type() == Function::SequenceType);
-            delete step;
             m_runnerSteps.removeOne(step);
+            delete step;
         }
         else
         {
