@@ -579,6 +579,9 @@ bool Doc::replaceFixtures(QList<Fixture*> newFixturesList)
         }
 
         newFixture->setExcludeFadeChannels(fixture->excludeFadeChannels());
+        newFixture->setForcedHTPChannels(fixture->forcedHTPChannels());
+        newFixture->setForcedLTPChannels(fixture->forcedLTPChannels());
+
         m_fixtures.insert(id, newFixture);
         m_fixturesListCacheUpToDate = false;
 
@@ -1234,7 +1237,7 @@ MonitorProperties *Doc::monitorProperties()
  * Load & Save
  *****************************************************************************/
 
-bool Doc::loadXML(QXmlStreamReader &doc)
+bool Doc::loadXML(QXmlStreamReader &doc, bool loadIO)
 {
     clearErrorLog();
 
@@ -1284,7 +1287,7 @@ bool Doc::loadXML(QXmlStreamReader &doc)
             /* LEGACY */
             Bus::instance()->loadXML(doc);
         }
-        else if (doc.name() == KXMLIOMap)
+        else if (doc.name() == KXMLIOMap && loadIO)
         {
             m_ioMap->loadXML(doc);
         }
