@@ -116,6 +116,8 @@ public:
     /** Set the duration in milliseconds */
     virtual void setDuration(uint ms);
 
+    uint loopDuration() const;
+
 signals:
     void durationChanged(uint ms);
 
@@ -477,6 +479,9 @@ public:
     /** Add a new fixture to this EFX */
     bool addFixture(EFXFixture *ef);
 
+    /** Add the provided fixture id and head to this EFX */
+    bool addFixture(quint32 fxi, int head = 0);
+
     /** Remove the designated fixture from this EFX but don't delete it */
     bool removeFixture(EFXFixture *ef);
 
@@ -514,9 +519,9 @@ private:
 public:
     enum PropagationMode
     {
-        Parallel, /**< All fixtures move in unison (el-cheapo) */
-        Serial, /**< Pattern propagates to the next fixture after a delay */
-        Asymmetric /**< All fixtures move with an offset */
+        Parallel,   /**< All fixtures move in unison (el-cheapo) */
+        Serial,     /**< Pattern propagates to the next fixture after a delay */
+        Asymmetric  /**< All fixtures move with an offset */
     };
 
     /** Set the EFX's fixture propagation mode (see the enum above) */
