@@ -213,6 +213,18 @@ void RGBScript::initEngine()
     Q_ASSERT(s_engine != NULL);
 }
 
+void RGBScript::displayError(QScriptValue e, const QString& fileName)
+{
+    if (e.isError()) 
+    {
+        QString msg("%1: Exception at line %2. Error: %3");
+        qWarning() << msg.arg(fileName)
+                         .arg(e.property("lineNumber").toInt32())
+                         .arg(e.toString());
+        qDebug() << "Stack: " << e.property("stack").toString();
+    }
+}
+
 /****************************************************************************
  * Script API
  ****************************************************************************/
@@ -227,8 +239,16 @@ int RGBScript::rgbMapStepCount(const QSize& size)
     QScriptValueList args;
     args << size.width() << size.height();
     QScriptValue value = m_rgbMapStepCount.call(QScriptValue(), args);
-    int ret = value.isNumber() ? value.toInteger() : -1;
-    return ret;
+    if (value.isError())
+    {
+        displayError(value, m_fileName);
+        return -1;
+    } 
+    else 
+    {
+        int ret = value.isNumber() ? value.toInteger() : -1;
+        return ret;
+    }
 }
 
 void RGBScript::rgbMap(const QSize& size, uint rgb, int step, RGBMap &map)
@@ -241,7 +261,11 @@ void RGBScript::rgbMap(const QSize& size, uint rgb, int step, RGBMap &map)
     QScriptValueList args;
     args << size.width() << size.height() << rgb << step;
     QScriptValue yarray = m_rgbMap.call(QScriptValue(), args);
-    if (yarray.isArray() == true)
+
+    if (yarray.isError())
+        displayError(yarray, m_fileName);
+
+    if (yarray.isArray())
     {
         int ylen = yarray.property("length").toInteger();
         map.resize(ylen);
@@ -349,8 +373,14 @@ QHash<QString, QString> RGBScript::propertiesAsStrings()
         {
             QScriptValueList args;
             QScriptValue value = readMethod.call(QScriptValue(), args);
-            if (value.isValid())
+            if (value.isError())
+            {
+                displayError(value, m_fileName);
+            }
+            else if (value.isValid())
+            {
                 properties.insert(cap.m_name, value.toString());
+            }
         }
     }
     return properties;
@@ -372,8 +402,16 @@ bool RGBScript::setProperty(QString propertyName, QString value)
             }
             QScriptValueList args;
             args << value;
-            writeMethod.call(QScriptValue(), args);
-            return true;
+            QScriptValue written = writeMethod.call(QScriptValue(), args);
+            if (written.isError())
+            {
+                displayError(written, m_fileName);
+                return false;
+            }
+            else
+            {
+                return true;
+            }
         }
     }
     return false;
@@ -395,10 +433,19 @@ QString RGBScript::property(QString propertyName) const
             }
             QScriptValueList args;
             QScriptValue value = readMethod.call(QScriptValue(), args);
-            if (value.isValid())
-                return value.toString();
-            else
+            if (value.isError())
+            {
+                displayError(value, m_fileName);
                 return QString();
+            }
+            else if (value.isValid())
+            {
+                return value.toString();
+            }
+            else
+            {
+                return QString();
+            }
         }
     }
     return QString();
