@@ -148,11 +148,7 @@ bool RGBScript::evaluate()
     m_script = s_engine->evaluate(m_contents, m_fileName);
     if (m_script.isError())
     {
-        QString msg("%1: Uncaught exception at line %2. Error: %3");
-        qWarning() << msg.arg(m_fileName)
-                         .arg(m_script.property("lineNumber").toInt())
-                         .arg(m_script.toString());
-        qDebug() << "Stack: " << m_script.property("stack").toString();
+        displayError(m_script, m_fileName);
         return false;
     }
 
@@ -199,6 +195,18 @@ void RGBScript::initEngine()
     Q_ASSERT(s_engine != NULL);
 }
 
+void RGBScript::displayError(QJSValue e, const QString& fileName)
+{
+    if (e.isError())
+    {
+        QString msg("%1: Exception at line %2. Error: %3");
+        qWarning() << msg.arg(fileName)
+                         .arg(e.property("lineNumber").toInt())
+                         .arg(e.toString());
+        qDebug() << "Stack: " << e.property("stack").toString();
+    }
+}
+
 /****************************************************************************
  * Script API
  ****************************************************************************/
@@ -213,8 +221,16 @@ int RGBScript::rgbMapStepCount(const QSize& size)
     QJSValueList args;
     args << size.width() << size.height();
     QJSValue value = m_rgbMapStepCount.call(args);
-    int ret = value.isNumber() ? value.toInt() : -1;
-    return ret;
+    if (value.isError())
+    {
+        displayError(value, m_fileName);
+        return -1;
+    } 
+    else 
+    {
+        int ret = value.isNumber() ? value.toInt() : -1;
+        return ret;
+    }
 }
 
 void RGBScript::rgbMap(const QSize& size, uint rgb, int step, RGBMap &map)
@@ -227,8 +243,10 @@ void RGBScript::rgbMap(const QSize& size, uint rgb, int step, RGBMap &map)
     QJSValueList args;
     args << size.width() << size.height() << rgb << step;
     QJSValue yarray(m_rgbMap.call(args));
+    if (yarray.isError())
+        displayError(yarray, m_fileName);
 
-    if (yarray.isArray() == true)
+    if (yarray.isArray())
     {
         QVariantList yvArray = yarray.toVariant().toList();
         int ylen = yvArray.length();
@@ -336,7 +354,9 @@ QHash<QString, QString> RGBScript::propertiesAsStrings()
         {
             QJSValueList args;
             QJSValue value = readMethod.call(args);
-            if (!value.isUndefined())
+            if (value.isError())
+                displayError(value, m_fileName);
+            else if (!value.isUndefined())
                 properties.insert(cap.m_name, value.toString());
         }
     }
@@ -359,8 +379,16 @@ bool RGBScript::setProperty(QString propertyName, QString value)
             }
             QJSValueList args;
             args << value;
-            writeMethod.call(args);
-            return true;
+            QJSValue written = writeMethod.call(args);
+            if (written.isError())
+            {
+                displayError(written, m_fileName);
+                return false;
+            } 
+            else 
+            {
+                return true;
+            }
         }
     }
     return false;
@@ -382,10 +410,19 @@ QString RGBScript::property(QString propertyName) const
             }
             QJSValueList args;
             QJSValue value = readMethod.call(args);
-            if (!value.isUndefined())
-                return value.toString();
-            else
+            if (value.isError())
+            {
+                displayError(value, m_fileName);
                 return QString();
+            } 
+            else if (!value.isUndefined())
+            {
+                return value.toString();
+            }
+            else
+            {
+                return QString();
+            }
         }
     }
     return QString();
