@@ -55,11 +55,11 @@ void Universe_Test::initial()
 
     QByteArray const preGM = m_uni->preGMValues();
 
-    QCOMPARE(preGM.count(), 512);
+    QCOMPARE(preGM.length(), 512);
 
     QByteArray const *postGM = m_uni->postGMValues();
     QVERIFY(postGM != NULL);
-    QCOMPARE(postGM->count(), 512);
+    QCOMPARE(postGM->length(), 512);
 
     for(ushort i = 0; i < 512; ++i)
     {
