@@ -256,7 +256,7 @@ void AlsaMidiOutputDevice::writeSysEx(QByteArray message)
     //snd_seq_ev_set_subs(&ev);
     snd_seq_ev_set_direct(&ev);
 
-    snd_seq_ev_set_sysex (&ev, message.count(), message.data());
+    snd_seq_ev_set_sysex (&ev, message.length(), message.data());
 
     if (snd_seq_event_output(m_alsa, &ev) < 0)
         qDebug() << "snd_seq_event_output ERROR";
