@@ -19,7 +19,7 @@
 */
 
 #include <QDebug>
-#include <usb.h>
+#include <libusb.h>
 
 #include "peperonidevice.h"
 #include "peperonidefs.h"
@@ -29,20 +29,23 @@
  * Initialization
  ****************************************************************************/
 
-PeperoniDevice::PeperoniDevice(Peperoni* parent, struct usb_device* device, quint32 line)
+PeperoniDevice::PeperoniDevice(Peperoni* parent, struct libusb_device* device,
+                               struct libusb_device_descriptor* desc,
+                               quint32 line)
     : QThread(parent)
     , m_baseLine(line)
     , m_device(device)
     , m_handle(NULL)
+    , m_descriptor(desc)
 {
     Q_ASSERT(device != NULL);
 
     /* Store fw version so we don't need to rely on libusb's volatile data */
-    m_firmwareVersion = m_device->descriptor.bcdDevice;
+    m_firmwareVersion = desc->bcdDevice;
     qDebug() << "[Peperoni] detected device firmware version:" << QString::number(m_firmwareVersion, 16);
 
     m_operatingModes[line] = CloseMode;
-    if (device->descriptor.idProduct == PEPERONI_PID_USBDMX21)
+    if (desc->idProduct == PEPERONI_PID_USBDMX21)
         m_operatingModes[line + 1] = CloseMode;
 
     extractName();
@@ -57,18 +60,18 @@ PeperoniDevice::~PeperoniDevice()
  * Device information
  ****************************************************************************/
 
-bool PeperoniDevice::isPeperoniDevice(const struct usb_device* device)
+bool PeperoniDevice::isPeperoniDevice(const struct libusb_device_descriptor* desc)
 {
     /* If there's nothing to inspect, it can't be what we're looking for */
-    if (device == NULL)
+    if (desc == NULL)
         return false;
 
     /* If it's not manufactured by them, we're not interested in it */
-    if (!isPeperoniDevice(device->descriptor.idVendor, device->descriptor.idProduct))
+    if (!isPeperoniDevice(desc->idVendor, desc->idProduct))
         return false;
 
     /* We need one interface */
-    if (device->config->bNumInterfaces < 1)
+    if (desc->bNumConfigurations < 1)
         return false;
 
     return true;
@@ -88,62 +91,71 @@ bool PeperoniDevice::isPeperoniDevice(int vid, int pid)
     return false;
 }
 
-int PeperoniDevice::outputsNumber(const struct usb_device *device)
+int PeperoniDevice::outputsNumber(libusb_device_descriptor *desc)
 {
     /* If there's nothing to inspect, it can't be what we're looking for */
-    if (device == NULL)
+    if (desc == NULL)
         return 0;
 
     /* If it's not manufactured by them, we're not interested in it */
-    if (device->descriptor.idVendor != PEPERONI_VID)
+    if (desc->idVendor != PEPERONI_VID)
         return 0;
 
-    if (device->descriptor.idProduct == PEPERONI_PID_USBDMX21)
+    if (desc->idProduct == PEPERONI_PID_USBDMX21)
+    {
         return 2;
-    else if (device->descriptor.idProduct == PEPERONI_PID_RODIN1     ||
-             device->descriptor.idProduct == PEPERONI_PID_RODIN1_MK3 ||
-             device->descriptor.idProduct == PEPERONI_PID_RODIN2     ||
-             device->descriptor.idProduct == PEPERONI_PID_RODINT     ||
-             device->descriptor.idProduct == PEPERONI_PID_XSWITCH)
-                return 1;
-    else
-        return 0;
+    }
+    else if (desc->idProduct == PEPERONI_PID_RODIN1     ||
+             desc->idProduct == PEPERONI_PID_RODIN1_MK3 ||
+             desc->idProduct == PEPERONI_PID_RODIN2     ||
+             desc->idProduct == PEPERONI_PID_RODINT     ||
+             desc->idProduct == PEPERONI_PID_XSWITCH)
+    {
+        return 1;
+    }
+
+    return 0;
 }
 
 void PeperoniDevice::extractName()
 {
-    bool needToClose = false;
-    char name[256];
-    int len;
-
     Q_ASSERT(m_device != NULL);
 
-    if (m_handle == NULL)
+    libusb_device_handle *handle = NULL;
+    int r = libusb_open(m_device, &handle);
+    if (r == 0)
     {
-        needToClose = true;
-        open(m_baseLine, OutputMode);
+        char buf[256];
+        int len = 0;
+
+        /* Extract the name */
+        len = libusb_get_string_descriptor_ascii(handle, m_descriptor->iProduct,
+                                               (uchar*) &buf, sizeof(buf));
+        if (len > 0)
+        {
+            m_name = QString(QByteArray(buf, len));
+        }
+        else
+        {
+            m_name = tr("Unknown");
+            qWarning() << "Unable to get product name:" << len;
+        }
+/*
+        // UID
+        len = libusb_get_string_descriptor_ascii(handle, m_descriptor->iSerialNumber,
+                                               (uchar*) &buf, sizeof(buf));
+        if (len > 0)
+            m_serial = QString(QByteArray(buf, len));
+        else
+            qWarning() << "Unable to get device serial:" << len;
+*/
     }
-
-    /* Check, whether open() was successful */
-    if (m_handle == NULL)
-        return;
-
-    /* Extract the name */
-    len = usb_get_string_simple(m_handle, m_device->descriptor.iProduct,
-                                name, sizeof(name));
-    if (len > 0)
-        m_name = QString(name);
-    else
-        m_name = tr("Unknown");
-
-    /* Close the device if it was opened for this function only. */
-    if (needToClose == true)
-        close(m_baseLine, OutputMode);
+    libusb_close(handle);
 }
 
 QString PeperoniDevice::name(quint32 line) const
 {
-    if (m_device->descriptor.idProduct == PEPERONI_PID_USBDMX21)
+    if (m_descriptor->idProduct == PEPERONI_PID_USBDMX21)
         return QString("%1 - %2 %3").arg(m_name).arg(tr("Universe")).arg((line - m_baseLine) + 1);
 
     return m_name;
@@ -221,32 +233,35 @@ bool PeperoniDevice::open(quint32 line, OperatingMode mode)
         int r = -1;
         int configuration = PEPERONI_CONF_TXRX;
 
-        m_handle = usb_open(m_device);
-        if (m_handle == NULL)
+        r = libusb_open(m_device, &m_handle);
+        if (r < 0)
         {
-            qWarning() << "Unable to open PeperoniDevice with idProduct:" << m_device->descriptor.idProduct;
+            qWarning() << "Unable to open PeperoniDevice with idProduct:" << m_descriptor->idProduct;
+            m_handle = NULL;
             return false;
         }
 
         /* Use configuration #2 on X-Switch */
-        if (m_device->descriptor.idProduct == PEPERONI_PID_XSWITCH)
+        if (m_descriptor->idProduct == PEPERONI_PID_XSWITCH)
             configuration = PEPERONI_CONF_TXRX;
         else
             configuration = PEPERONI_CONF_TXONLY;
 
         /* Set selected configuration */
-        r = usb_set_configuration(m_handle, configuration);
+        r = libusb_set_configuration(m_handle, configuration);
         if (r < 0)
             qWarning() << "PeperoniDevice is unable to set configuration #" << configuration;
 
         /* We must claim the interface before doing anything */
-        r = usb_claim_interface(m_handle, PEPERONI_IFACE_EP0);
+        r = libusb_claim_interface(m_handle, PEPERONI_IFACE_EP0);
         if (r < 0)
             qWarning() << "PeperoniDevice is unable to claim interface EP0!";
 
-        /* Set DMX startcode */
-        r = usb_control_msg(m_handle,
-                            USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_OUT,
+        /* Set TX DMX startcode */
+        r = libusb_control_transfer(m_handle,
+                            LIBUSB_REQUEST_TYPE_VENDOR |
+                            LIBUSB_RECIPIENT_INTERFACE |
+                            LIBUSB_ENDPOINT_OUT,
                             PEPERONI_TX_STARTCODE,   // Set DMX startcode
                             0,                       // Standard startcode is 0
                             0,                       // No index
@@ -256,9 +271,11 @@ bool PeperoniDevice::open(quint32 line, OperatingMode mode)
         if (r < 0)
             qWarning() << "PeperoniDevice is unable to set 0 as the DMX output startcode!";
 
-        /* Set DMX startcode */
-        r = usb_control_msg(m_handle,
-                            USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_OUT,
+        /* Set RX DMX startcode */
+        r = libusb_control_transfer(m_handle,
+                            LIBUSB_REQUEST_TYPE_VENDOR |
+                            LIBUSB_RECIPIENT_INTERFACE |
+                            LIBUSB_ENDPOINT_IN,
                             PEPERONI_RX_STARTCODE,   // Set DMX startcode
                             0,                       // Standard startcode is 0
                             0,                       // No index
@@ -266,15 +283,15 @@ bool PeperoniDevice::open(quint32 line, OperatingMode mode)
                             0,                       // Zero data length
                             50);                     // Timeout (ms)
         if (r < 0)
-            qWarning() << "PeperoniDevice is unable to set 0 as the DMX output startcode!";
+            qWarning() << "PeperoniDevice is unable to set 0 as the DMX input startcode!";
 
         if (m_firmwareVersion >= PEPERONI_FW_OLD_BULK_SUPPORT)
         {
             /* Sometimes you need a little jolt to get the device on its feet. */
-            r = usb_clear_halt(m_handle, PEPERONI_BULK_OUT_ENDPOINT);
+            r = libusb_clear_halt(m_handle, PEPERONI_BULK_OUT_ENDPOINT);
             if (r < 0)
                 qWarning() << "PeperoniDevice" << name(m_baseLine) << "is unable to reset bulk OUT endpoint.";
-            r = usb_clear_halt(m_handle, PEPERONI_BULK_IN_ENDPOINT);
+            r = libusb_clear_halt(m_handle, PEPERONI_BULK_IN_ENDPOINT);
             if (r < 0)
                 qWarning() << "PeperoniDevice" << name(m_baseLine) << "is unable to reset bulk IN endpoint.";
         }
@@ -304,17 +321,19 @@ void PeperoniDevice::close(quint32 line, OperatingMode mode)
     if (m_operatingModes[line] != CloseMode)
         return;
 
+    QMutexLocker lock(&m_ioMutex);
+
     if (m_device != NULL && m_handle != NULL)
     {
         /* Release the interface in case we claimed it */
-        int r = usb_release_interface(m_handle, PEPERONI_IFACE_EP0);
+        int r = libusb_release_interface(m_handle, PEPERONI_IFACE_EP0);
         if (r < 0)
         {
             qWarning() << "PeperoniDevice" << name(m_baseLine)
                        << "is unable to release interface EP0!";
         }
 
-        usb_close(m_handle);
+        libusb_close(m_handle);
     }
 
     m_handle = NULL;
@@ -328,15 +347,11 @@ void PeperoniDevice::closeAll()
     close(m_baseLine, OutputMode);
 }
 
-const struct usb_device* PeperoniDevice::device() const
+const struct libusb_device* PeperoniDevice::device() const
 {
     return m_device;
 }
 
-const usb_dev_handle* PeperoniDevice::handle() const
-{
-    return m_handle;
-}
 
 /****************************************************************************
  * Input Thread
@@ -344,7 +359,7 @@ const usb_dev_handle* PeperoniDevice::handle() const
 
 void PeperoniDevice::run()
 {
-    if (m_handle == NULL)
+    if (m_device == NULL)
         return;
 
     qDebug() << "[Peperoni] input thread started correctly";
@@ -380,48 +395,54 @@ void PeperoniDevice::run()
             int r = -1;
             QMutexLocker lock(&m_ioMutex);
 
-            r = usb_control_msg(m_handle,
-                                USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
-                                PEPERONI_RX_MEM_REQUEST, // We are WRITING DMX data
-                                block,                   // Blocking does not work on all firmware versions -> don't block
-                                0,                       // Start at DMX address 0
-                                tmpBuffer.data(),        // The DMX universe data
-                                tmpBuffer.size(),        // Size of DMX universe
-                                100);                    // Timeout (ms)
+            r = libusb_control_transfer(m_handle,
+                                LIBUSB_REQUEST_TYPE_VENDOR |
+                                LIBUSB_RECIPIENT_INTERFACE |
+                                LIBUSB_ENDPOINT_IN,
+                                PEPERONI_RX_MEM_REQUEST,   // We are READING DMX data
+                                block,                     // Blocking does not work on all firmware versions -> don't block
+                                0,                         // Start at DMX address 0
+                                (uchar *)tmpBuffer.data(), // The DMX universe data
+                                tmpBuffer.size(),          // Size of DMX universe
+                                100);                      // Timeout (ms)
 
             if (r < 0)
             {
-                qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed control_msg:" << usb_strerror();
-                r = usb_clear_halt(m_handle, PEPERONI_BULK_IN_ENDPOINT);
+                qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed control_msg:" << libusb_strerror(libusb_error(r));
+                r = libusb_clear_halt(m_handle, PEPERONI_BULK_IN_ENDPOINT);
                 if (r < 0)
                     qWarning() << "PeperoniDevice" << name(m_baseLine) << "is unable to reset bulk IN endpoint.";
             }
             else
             {
                 /* read received startcode */
-                r = usb_control_msg(m_handle,
-                                    USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
+                r = libusb_control_transfer(m_handle,
+                                    LIBUSB_REQUEST_TYPE_VENDOR |
+                                    LIBUSB_RECIPIENT_INTERFACE |
+                                    LIBUSB_ENDPOINT_IN,
                                     PEPERONI_RX_STARTCODE,
                                     0,
                                     0,
-                                    (char *)&rxstartcode,
+                                    (uchar *)&rxstartcode,
                                     sizeof(rxstartcode),
                                     10);
                 if (r < 0)
-                    qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed to read receiver startcode:" << usb_strerror();
+                    qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed to read receiver startcode:" << libusb_strerror(libusb_error(r));
                 else
                 {
                     /* read number of received slots */
-                    r = usb_control_msg(m_handle,
-                                        USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_IN,
+                    r = libusb_control_transfer(m_handle,
+                                        LIBUSB_REQUEST_TYPE_VENDOR |
+                                        LIBUSB_RECIPIENT_INTERFACE |
+                                        LIBUSB_ENDPOINT_IN,
                                         PEPERONI_RX_SLOTS,
                                         0,
                                         0,
-                                        (char *)&rxslots,
+                                        (uchar *)&rxslots,
                                         sizeof(rxslots),
                                         10);
                     if (r < 0)
-                        qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed to read receiver slot counter:" << usb_strerror();
+                        qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed to read receiver slot counter:" << libusb_strerror(libusb_error(r));
                     else
                     {
                         if (rxslots > m_dmxInputBuffer.size())
@@ -480,17 +501,20 @@ void PeperoniDevice::outputDMX(quint32 line, const QByteArray& universe)
     {
 #endif
         //qDebug() << "[Peperoni] control pipe write. size:" << universe.size();
-        r = usb_control_msg(m_handle,
-                            USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_ENDPOINT_OUT,
-                            PEPERONI_TX_MEM_REQUEST, // We are WRITING DMX data
-                            0,                       // Blocking does not work on all firmware versions -> don't block
-                            0,                       // Start at DMX address 0
-                            (char*) universe.data(), // The DMX universe data
-                            universe.size(),         // Size of DMX universe
-                            50);                     // Timeout (ms)
+        r = libusb_control_transfer(m_handle,
+                            LIBUSB_REQUEST_TYPE_VENDOR |
+                            LIBUSB_RECIPIENT_INTERFACE |
+                            LIBUSB_ENDPOINT_OUT,
+                            PEPERONI_TX_MEM_REQUEST,  // We are WRITING DMX data
+                            0,                        // Blocking does not work on all firmware versions -> don't block
+                            0,                        // Start at DMX address 0
+                            (uchar*) universe.data(), // The DMX universe data
+                            universe.size(),          // Size of DMX universe
+                            50);                      // Timeout (ms)
 
         if (r < 0)
-            qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed control write:" << usb_strerror();
+            qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed control write:" << libusb_strerror(libusb_error(r));
+
 #if !defined(__APPLE__) && !defined(Q_OS_MAC)
     }
     else if (m_firmwareVersion < PEPERONI_FW_NEW_BULK_SUPPORT)
@@ -513,14 +537,19 @@ void PeperoniDevice::outputDMX(quint32 line, const QByteArray& universe)
         m_bulkBuffer.append(QByteArray(int(512 - universe.size()), char(0)));
 
         /* Perform a bulk write */
-        r = usb_bulk_write(m_handle, PEPERONI_BULK_OUT_ENDPOINT,
-                           m_bulkBuffer.data(), m_bulkBuffer.size(), 50);
+        int written = 0;
+        r = libusb_bulk_transfer(m_handle,
+                                 PEPERONI_BULK_OUT_ENDPOINT,
+                                 (uchar *)m_bulkBuffer.data(),
+                                 m_bulkBuffer.size(),
+                                 &written,
+                                 50);
 
         if (r < 0)
         {
-            qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed 'old' bulk write:" << usb_strerror();
+            qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed 'old' bulk write:" << libusb_strerror(libusb_error(r));
             qWarning() << "Resetting bulk endpoint.";
-            r = usb_clear_halt(m_handle, PEPERONI_BULK_OUT_ENDPOINT);
+            r = libusb_clear_halt(m_handle, PEPERONI_BULK_OUT_ENDPOINT);
             if (r < 0)
                 qWarning() << "PeperoniDevice" << name(m_baseLine) << "is unable to reset bulk endpoint.";
         }
@@ -564,30 +593,39 @@ void PeperoniDevice::outputDMX(quint32 line, const QByteArray& universe)
         m_bulkBuffer.append(QByteArray(int(512 - universe.size()), char(0)));
 
         /* Perform a bulk write */
-        r = usb_bulk_write(m_handle, PEPERONI_BULK_OUT_ENDPOINT,
-                           m_bulkBuffer.data(), m_bulkBuffer.size(),
-                           100); /* use larger timeout then specified in the command header above */
+        int written = 0;
+        r = libusb_bulk_transfer(m_handle,
+                                 PEPERONI_BULK_OUT_ENDPOINT,
+                                 (uchar *)m_bulkBuffer.data(),
+                                 m_bulkBuffer.size(),
+                                 &written,
+                                 100); /* use larger timeout then specified in the command header above */
         if (r < 0)
         {
-            qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed 'new' bulk write:" << usb_strerror();
+            qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed 'new' bulk write:" << libusb_strerror(libusb_error(r));
         }
         else
         {
             char status[8];
-            r = usb_bulk_read(m_handle, PEPERONI_BULK_IN_ENDPOINT,
-                              status, sizeof(status),
-                              100); /* use larger timeout then specified in the command header above */
+            int read = 0;
+            r = libusb_bulk_transfer(m_handle,
+                                     PEPERONI_BULK_IN_ENDPOINT,
+                                     (uchar *)status,
+                                     sizeof(status),
+                                     &read,
+                                     100); /* use larger timeout then specified in the command header above */
             if (r < 0)
-                qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed 'new' bulk read:" << usb_strerror();
+                qWarning() << "PeperoniDevice" << name(m_baseLine) << "failed 'new' bulk read:" << libusb_strerror(libusb_error(r));
         }
 
         if (r < 0)
         {
             qWarning() << "Resetting bulk endpoints.";
-            r = usb_clear_halt(m_handle, PEPERONI_BULK_OUT_ENDPOINT);
+            r = libusb_clear_halt(m_handle, PEPERONI_BULK_OUT_ENDPOINT);
             if (r < 0)
                 qWarning() << "PeperoniDevice" << name(m_baseLine) << "is unable to reset bulk OUT endpoint.";
-            r = usb_clear_halt(m_handle, PEPERONI_BULK_IN_ENDPOINT);
+
+            r = libusb_clear_halt(m_handle, PEPERONI_BULK_IN_ENDPOINT);
             if (r < 0)
                 qWarning() << "PeperoniDevice" << name(m_baseLine) << "is unable to reset bulk IN endpoint.";
         }
