@@ -33,9 +33,10 @@
 #include <QPrinter>
 #include <QPainter>
 #include <QScreen>
+#include <unistd.h>
 
 #include "app.h"
-#include "mainview2d.h"
+#include "uimanager.h"
 #include "simpledesk.h"
 #include "showmanager.h"
 #include "fixtureeditor.h"
@@ -57,7 +58,6 @@
 #include "qlcfixturedefcache.h"
 #include "audioplugincache.h"
 #include "rgbscriptscache.h"
-#include "qlcfixturedef.h"
 #include "qlcconfig.h"
 #include "qlcfile.h"
 
@@ -77,6 +77,8 @@ App::App()
     , m_showManager(nullptr)
     , m_simpleDesk(nullptr)
     , m_videoProvider(nullptr)
+    , m_networkManager(nullptr)
+    , m_uiManager(nullptr)
     , m_doc(nullptr)
     , m_docLoaded(false)
     , m_printItem(nullptr)
@@ -131,13 +133,12 @@ void App::startup()
 
     rootContext()->setContextProperty("qlcplus", this);
 
-    m_pixelDensity = qMax(screen()->physicalDotsPerInch() *  0.039370, (qreal)screen()->size().height() / 220.0);
-    qDebug() << "Pixel density:" << m_pixelDensity << "size:" << screen()->physicalSize();
-
-    rootContext()->setContextProperty("screenPixelDensity", m_pixelDensity);
+    slotScreenChanged(screen());
 
     initDoc();
 
+    m_uiManager = new UiManager(this, m_doc);
+    rootContext()->setContextProperty("uiManager", m_uiManager);
     m_ioManager = new InputOutputManager(this, m_doc);
     m_fixtureBrowser = new FixtureBrowser(this, m_doc);
     m_fixtureManager = new FixtureManager(this, m_doc);
@@ -174,6 +175,8 @@ void App::startup()
     // Start up in non-modified state
     m_doc->resetModified();
 
+    m_uiManager->initialize();
+
     // and here we go !
     setSource(QUrl("qrc:/MainView.qml"));
 }
@@ -218,6 +221,11 @@ void App::setLanguage(QString locale)
     engine()->retranslate();
 }
 
+QString App::goboSystemPath() const
+{
+    return QLCFile::systemDirectory(GOBODIR).absolutePath();
+}
+
 void App::show()
 {
     QScreen *currScreen = screen();
@@ -317,8 +325,12 @@ void App::slotSceneGraphInitialized()
 
 void App::slotScreenChanged(QScreen *screen)
 {
-    m_pixelDensity = qMax(screen->physicalDotsPerInch() *  0.039370, (qreal)screen->size().height() / 220.0);
-    qDebug() << "Screen changed to" << screen->name() << ". New pixel density:" << m_pixelDensity;
+    bool isLandscape = (screen->orientation() == Qt::LandscapeOrientation ||
+                     screen->orientation() == Qt::InvertedLandscapeOrientation) ? true : false;
+    qreal sSize = isLandscape ? screen->size().height() : screen->size().width();
+    m_pixelDensity = qMax(screen->physicalDotsPerInch() *  0.039370, sSize / 220.0);
+    qDebug() << "Screen changed to" << screen->name() << ", pixel density:" << m_pixelDensity
+             << ", physical size:" << screen->physicalSize();
     rootContext()->setContextProperty("screenPixelDensity", m_pixelDensity);
 }
 
@@ -342,32 +354,19 @@ void App::slotAccessMaskChanged(int mask)
     setAccessMask(mask);
 }
 
-void App::clearDocument()
-{
-    if (m_videoProvider)
-    {
-        delete m_videoProvider;
-        m_videoProvider = nullptr;
-    }
-
-    m_doc->masterTimer()->stop();
-    m_doc->clearContents();
-    m_virtualConsole->resetContents();
-    //SimpleDesk::instance()->clearContents();
-    m_showManager->resetContents();
-    m_tardis->resetHistory();
-    m_doc->inputOutputMap()->resetUniverses();
-    setFileName(QString());
-    m_doc->resetModified();
-    m_doc->inputOutputMap()->startUniverses();
-    m_doc->masterTimer()->start();
-}
-
+/*********************************************************************
+ * Doc
+ *********************************************************************/
 Doc *App::doc()
 {
     return m_doc;
 }
 
+bool App::docLoaded()
+{
+    return m_docLoaded;
+}
+
 bool App::docModified() const
 {
     return m_doc->isModified();
@@ -379,6 +378,8 @@ void App::initDoc()
     m_doc = new Doc(this);
 
     connect(m_doc, SIGNAL(modified(bool)), this, SIGNAL(docModifiedChanged()));
+    connect(m_doc->masterTimer(), SIGNAL(functionListChanged()),
+            this, SIGNAL(runningFunctionsCountChanged()));
 
     /* Load user fixtures first so that they override system fixtures */
     m_doc->fixtureDefCache()->load(QLCFixtureDefCache::userDefinitionDirectory());
@@ -419,6 +420,44 @@ void App::initDoc()
     m_doc->masterTimer()->start();
 }
 
+void App::clearDocument()
+{
+    if (m_videoProvider)
+    {
+        delete m_videoProvider;
+        m_videoProvider = nullptr;
+    }
+
+    m_contextManager->resetFixtureSelection();
+    //m_simpleDesk->resetContents(); // TODO
+    m_showManager->resetContents();
+    m_virtualConsole->resetContents();
+
+    m_doc->masterTimer()->stop();
+    m_doc->clearContents();
+
+    m_tardis->resetHistory();
+    m_doc->inputOutputMap()->resetUniverses();
+    setFileName(QString());
+    m_doc->resetModified();
+    m_doc->inputOutputMap()->startUniverses();
+    m_doc->masterTimer()->start();
+}
+
+int App::runningFunctionsCount() const
+{
+    return m_doc->masterTimer()->runningFunctions();
+}
+
+void App::stopAllFunctions()
+{
+    // first, gracefully stop via Function Manager (if that's the case)
+    m_functionManager->setPreviewEnabled(false);
+
+    // then, brutally kill the rest (could be started from VC, etc)
+    m_doc->masterTimer()->stopAllFunctions();
+}
+
 void App::enableKioskMode()
 {
     // enable Virtual console only
@@ -880,6 +919,7 @@ void App::importFromWorkspace()
         return;
 
     m_importManager->apply();
+    m_paletteManager->updatePaletteList();
 
     delete m_importManager;
     m_importManager = nullptr;
@@ -916,14 +956,27 @@ void App::loadFixture(QString fileName)
 
 void App::editFixture(QString manufacturer, QString model)
 {
+    bool switchToEditor = false;
+
     if (m_fixtureEditor == nullptr)
     {
         m_fixtureEditor = new FixtureEditor(this, m_doc);
+        switchToEditor = true;
+    }
+
+    if (m_fixtureEditor->editDefinition(manufacturer, model) == false)
+    {
+        delete m_fixtureEditor;
+        m_fixtureEditor = nullptr;
+        return;
+    }
+
+    if (switchToEditor)
+    {
         QMetaObject::invokeMethod(rootObject(), "switchToContext",
                                   Q_ARG(QVariant, "FXEDITOR"),
                                   Q_ARG(QVariant, "qrc:/FixtureEditor.qml"));
     }
-    m_fixtureEditor->editDefinition(manufacturer, model);
 }
 
 void App::closeFixtureEditor()
