@@ -32,7 +32,6 @@
 #include "mainviewdmx.h"
 #include "mainview2d.h"
 #include "mainview3d.h"
-#include "simpledesk.h"
 #include "tardis.h"
 #include "app.h"
 #include "doc.h"
@@ -88,9 +87,6 @@ ContextManager::ContextManager(QQuickView *view, Doc *doc,
     connect(m_fixtureManager, &FixtureManager::fixtureFlagsChanged, this, &ContextManager::slotFixtureFlagsChanged);
 
     connect(m_fixtureManager, &FixtureManager::channelValueChanged, this, &ContextManager::slotChannelValueChanged);
-    connect(m_fixtureManager, SIGNAL(channelTypeValueChanged(int, quint8)),
-            this, SLOT(slotChannelTypeValueChanged(int, quint8)));
-    connect(m_fixtureManager, &FixtureManager::colorChanged, this, &ContextManager::slotColorChanged);
     connect(m_fixtureManager, &FixtureManager::presetChanged, this, &ContextManager::slotPresetChanged);
 
     connect(m_doc->inputOutputMap(), SIGNAL(universeWritten(quint32,QByteArray)), this, SLOT(slotUniverseWritten(quint32,QByteArray)));
@@ -291,7 +287,9 @@ void ContextManager::setPositionPickPoint(QVector3D point)
     if (positionPicking() == false)
         return;
 
-    point = QVector3D(point.x() + m_monProps->gridSize().x() / 2, point.y(), point.z() + m_monProps->gridSize().z() / 2);
+    point = QVector3D(point.x() + m_monProps->gridSize().x() / 2,
+                      point.y(),
+                      point.z() + m_monProps->gridSize().z() / 2);
 
     for (quint32 itemID : m_selectedFixtures)
     {
@@ -303,6 +301,9 @@ void ContextManager::setPositionPickPoint(QVector3D point)
 
         quint32 panMSB = fixture->channelNumber(QLCChannel::Pan, QLCChannel::MSB);
         quint32 tiltMSB = fixture->channelNumber(QLCChannel::Tilt, QLCChannel::MSB);
+        int linkedIndex = FixtureUtils::itemLinkedIndex(itemID);
+        int headIndex = FixtureUtils::itemHeadIndex(itemID);
+        quint32 itemFlags = m_monProps->fixtureFlags(fxID, headIndex, linkedIndex);
 
         // don't even bother if the fixture doesn't have PAN/TILT channels
         if (panMSB == QLCChannel::invalid() && tiltMSB == QLCChannel::invalid())
@@ -346,9 +347,16 @@ void ContextManager::setPositionPickPoint(QVector3D point)
             else if(!xLeft && zBack)
                 panDeg = 270.0 + (90.0 - panDeg);
 
+            if (itemFlags & MonitorProperties::InvertedPanFlag)
+            {
+                QLCPhysical phy = fixture->fixtureMode()->physical();
+                double maxPanDeg = phy.focusPanMax() ? phy.focusPanMax() : 360;
+                panDeg = maxPanDeg - panDeg;
+            }
+
             qDebug() << "Fixture" << fxID << "pan degrees:" << panDeg;
 
-            QList<SceneValue> svList = m_fixtureManager->getFixturePosition(fxID, QLCChannel::Pan, panDeg);
+            QList<SceneValue> svList = fixture->positionToValues(QLCChannel::Pan, panDeg);
             for (SceneValue posSv : svList)
             {
                 if (m_editingEnabled == false)
@@ -366,7 +374,6 @@ void ContextManager::setPositionPickPoint(QVector3D point)
             QVector3D ya = QVector3D(res.x(), res.y(), res.z());
 
             qreal tiltDeg =  qRadiansToDegrees(qAcos(QVector3D::dotProduct(dir, ya)));
-
             QLCPhysical phy = fixture->fixtureMode()->physical();
 
             // clamp the tilt.
@@ -376,11 +383,14 @@ void ContextManager::setPositionPickPoint(QVector3D point)
             if (tiltDeg > phy.focusTiltMax() / 2)
                 tiltDeg = phy.focusTiltMax() / 2;
 
-            tiltDeg = phy.focusTiltMax() / 2 - tiltDeg;
+            if (itemFlags & MonitorProperties::InvertedTiltFlag)
+                tiltDeg = phy.focusTiltMax() / 2 + tiltDeg;
+            else
+                tiltDeg = phy.focusTiltMax() / 2 - tiltDeg;
 
             qDebug() << "Fixture" << fxID << "tilt degrees:" << tiltDeg;
 
-            QList<SceneValue> svList = m_fixtureManager->getFixturePosition(fxID, QLCChannel::Tilt, tiltDeg);
+            QList<SceneValue> svList = fixture->positionToValues(QLCChannel::Tilt, tiltDeg);
             for (SceneValue posSv : svList)
             {
                 if (m_editingEnabled == false)
@@ -433,11 +443,14 @@ void ContextManager::handleKeyPress(QKeyEvent *e)
             case Qt::Key_A:
                 toggleFixturesSelection();
             break;
+            case Qt::Key_P:
+                setPositionPicking(true);
+            break;
             case Qt::Key_R:
                 resetDumpValues();
             break;
-            case Qt::Key_P:
-                setPositionPicking(true);
+            case Qt::Key_S:
+                QMetaObject::invokeMethod(m_view->rootObject(), "saveProject");
             break;
             case Qt::Key_Z:
                 if (e->modifiers() & Qt::ShiftModifier)
@@ -451,7 +464,7 @@ void ContextManager::handleKeyPress(QKeyEvent *e)
     }
 
 
-    for(PreviewContext *context : m_contextsMap.values()) // C++11
+    for (PreviewContext *context : m_contextsMap.values()) // C++11
         context->handleKeyEvent(e, true);
 }
 
@@ -465,7 +478,7 @@ void ContextManager::handleKeyRelease(QKeyEvent *e)
 
     qDebug() << "Key release event received:" << e->text();
 
-    for(PreviewContext *context : m_contextsMap.values()) // C++11
+    for (PreviewContext *context : m_contextsMap.values()) // C++11
         context->handleKeyEvent(e, false);
 }
 
@@ -554,6 +567,8 @@ void ContextManager::setFixtureSelection(quint32 itemID, int headIndex, bool ena
     emit dumpValuesCountChanged();
 
     Fixture *fixture = m_doc->fixture(fixtureID);
+    if (fixture == nullptr)
+        return;
 
     if (m_DMXView->isEnabled())
         m_DMXView->updateFixtureSelection(fixtureID, enable);
@@ -863,6 +878,7 @@ void ContextManager::setFixturesGelColor(QColor color)
         if (m_3DView->isEnabled())
             m_3DView->updateFixtureItem(fixture, headIndex, linkedIndex, ba);
     }
+    m_doc->setModified();
 }
 
 void ContextManager::setFixturesAlignment(int alignment)
@@ -889,6 +905,7 @@ void ContextManager::setFixturesAlignment(int alignment)
         if (m_3DView->isEnabled())
             m_3DView->updateFixturePosition(itemID, fxPos);
     }
+    m_doc->setModified();
 }
 
 void ContextManager::setFixturesDistribution(int direction)
@@ -1005,6 +1022,7 @@ void ContextManager::setFixturesDistribution(int direction)
 
         newPos += size + gap;
     }
+    m_doc->setModified();
 }
 
 void ContextManager::setLinkedFixture(quint32 itemID)
@@ -1079,6 +1097,66 @@ void ContextManager::updateFixturesCapabilities()
         m_fixtureManager->getFixtureCapabilities(itemID, -1, true);
 }
 
+qreal ContextManager::getCurrentValue(int type, bool degrees)
+{
+    qreal currMsbValue = -1;
+    qreal currLsbValue = -1;
+    qreal currValue = -1;
+
+    QList<SceneValue> svList = m_channelsMap.values(type);
+    for (SceneValue &sv : svList)
+    {
+        Fixture *fixture = m_doc->fixture(sv.fxi);
+        if (fixture == nullptr)
+            continue;
+
+        const QLCChannel *ch = fixture->channel(sv.channel);
+        if (ch == nullptr)
+            continue;
+
+        qreal chValue = fixture->channelValueAt(sv.channel);
+
+        if (ch->controlByte() == QLCChannel::MSB)
+        {
+            if (degrees)
+            {
+                QLCFixtureMode *fxMode = fixture->fixtureMode();
+                QLCPhysical phy = fxMode->physical();
+                if (type == QLCChannel::Pan)
+                    chValue = (qreal(phy.focusPanMax()) / 256.0) * chValue;
+                else if (type == QLCChannel::Tilt)
+                    chValue = (qreal(phy.focusTiltMax()) / 256.0) * chValue;
+            }
+            if (currMsbValue != -1 && currMsbValue != chValue)
+                return -1;
+
+            currMsbValue = chValue;
+        }
+        else if (ch->controlByte() == QLCChannel::LSB)
+        {
+            if (degrees)
+            {
+                QLCFixtureMode *fxMode = fixture->fixtureMode();
+                QLCPhysical phy = fxMode->physical();
+                if (type == QLCChannel::Pan)
+                    chValue = (qreal(phy.focusPanMax()) / 65536.0) * chValue;
+                else if (type == QLCChannel::Tilt)
+                    chValue = (qreal(phy.focusTiltMax()) / 65536.0) * chValue;
+            }
+
+            if (currLsbValue != -1 && currLsbValue != chValue)
+                return -1;
+
+            currLsbValue = chValue;
+        }
+    }
+
+    qDebug() << "Channel type" << type << "MSB" << currMsbValue << "LSB" << currLsbValue;
+    currValue = currMsbValue + currLsbValue / 255.0;
+
+    return currValue;
+}
+
 void ContextManager::createFixtureGroup()
 {
     if (m_selectedFixtures.isEmpty())
@@ -1239,53 +1317,72 @@ void ContextManager::slotChannelValueChanged(quint32 fxID, quint32 channel, quin
         m_functionManager->setChannelValue(fxID, channel, uchar(value));
 }
 
-void ContextManager::slotChannelTypeValueChanged(int type, quint8 value, quint32 channel)
+void ContextManager::setColorValue(QColor col, QColor wauv)
 {
-    //qDebug() << "type:" << type << "value:" << value << "channel:" << channel;
+    setChannelValueByType((int)QLCChannel::Red, col.red());
+    setChannelValueByType((int)QLCChannel::Green, col.green());
+    setChannelValueByType((int)QLCChannel::Blue, col.blue());
+
+    setChannelValueByType((int)QLCChannel::White, wauv.red());
+    setChannelValueByType((int)QLCChannel::Amber, wauv.green());
+    setChannelValueByType((int)QLCChannel::UV, wauv.blue());
+
+    QColor cmykColor = col.toCmyk();
+    setChannelValueByType((int)QLCChannel::Cyan, cmykColor.cyan());
+    setChannelValueByType((int)QLCChannel::Magenta, cmykColor.magenta());
+    setChannelValueByType((int)QLCChannel::Yellow, cmykColor.yellow());
+}
+
+void ContextManager::setChannelValueByType(int type, int value, bool isRelative, quint32 channel)
+{
+    //qDebug() << "[setChannelValueByType] type:" << type << "value:" << value << "relative:" << isRelative << "channel:" << channel;
     QList<SceneValue> svList = m_channelsMap.values(type);
-    for (SceneValue sv : svList)
+    for (SceneValue &sv : svList)
     {
         if (channel == UINT_MAX || channel == sv.channel)
         {
+            uchar val = value;
+
+            if (isRelative)
+            {
+                Fixture *fixture = m_doc->fixture(sv.fxi);
+                if (fixture == nullptr)
+                    continue;
+
+                const QLCChannel *ch = fixture->channel(sv.channel);
+                if (ch == nullptr)
+                    continue;
+
+                val = qBound(0, fixture->channelValueAt(sv.channel) + value, 255);
+            }
+
             if (m_editingEnabled == false)
-                setDumpValue(sv.fxi, sv.channel, uchar(value));
+                setDumpValue(sv.fxi, sv.channel, val);
             else
-                m_functionManager->setChannelValue(sv.fxi, sv.channel, uchar(value));
+                m_functionManager->setChannelValue(sv.fxi, sv.channel, val);
         }
     }
 }
 
-void ContextManager::slotColorChanged(QColor col, QColor wauv)
-{
-    slotChannelTypeValueChanged((int)QLCChannel::Red, (quint8)col.red());
-    slotChannelTypeValueChanged((int)QLCChannel::Green, (quint8)col.green());
-    slotChannelTypeValueChanged((int)QLCChannel::Blue, (quint8)col.blue());
-
-    slotChannelTypeValueChanged((int)QLCChannel::White, (quint8)wauv.red());
-    slotChannelTypeValueChanged((int)QLCChannel::Amber, (quint8)wauv.green());
-    slotChannelTypeValueChanged((int)QLCChannel::UV, (quint8)wauv.blue());
-
-    QColor cmykColor = col.toCmyk();
-    slotChannelTypeValueChanged((int)QLCChannel::Cyan, (quint8)cmykColor.cyan());
-    slotChannelTypeValueChanged((int)QLCChannel::Magenta, (quint8)cmykColor.magenta());
-    slotChannelTypeValueChanged((int)QLCChannel::Yellow, (quint8)cmykColor.yellow());
-}
-
-void ContextManager::setPositionValue(int type, int degrees)
+void ContextManager::setPositionValue(int type, int degrees, bool isRelative)
 {
     // list to keep track of the already processed Fixture IDs
     QList<quint32>fxIDs;
     QList<SceneValue> typeList = m_channelsMap.values(type);
 
-    for (SceneValue sv : typeList)
+    for (SceneValue &sv : typeList)
     {
         if (fxIDs.contains(sv.fxi) == true)
             continue;
 
         fxIDs.append(sv.fxi);
 
-        QList<SceneValue> svList = m_fixtureManager->getFixturePosition(sv.fxi, type, degrees);
-        for (SceneValue posSv : svList)
+        Fixture *fixture = m_doc->fixture(sv.fxi);
+        if (fixture == nullptr || fixture->fixtureMode() == nullptr)
+            continue;
+
+        QList<SceneValue> svList = fixture->positionToValues(type, degrees, isRelative);
+        for (SceneValue &posSv : svList)
         {
             if (m_editingEnabled == false)
                 setDumpValue(posSv.fxi, posSv.channel, posSv.value);
@@ -1343,7 +1440,7 @@ void ContextManager::slotPresetChanged(const QLCChannel *channel, quint8 value)
         {
             quint32 chIdx = fixture->fixtureMode()->channelNumber((QLCChannel *)channel);
             if (chIdx != QLCChannel::invalid())
-                slotChannelTypeValueChanged((int)channel->group(), value, chIdx);
+                setChannelValueByType((int)channel->group(), value, false, chIdx);
         }
     }
 }
