@@ -26,6 +26,7 @@
 #include <QDir>
 
 #include "monitorproperties.h"
+#include "channelmodifier.h"
 #include "fixturemanager.h"
 #include "qlcfixturemode.h"
 #include "qlccapability.h"
@@ -56,6 +57,7 @@ FixtureManager::FixtureManager(QQuickView *view, Doc *doc, QObject *parent)
     , m_maxBeamDegrees(0)
     , m_invertedZoom(false)
     , m_colorsMask(0)
+    , m_selectedChannelModifier(nullptr)
 {
     Q_ASSERT(m_doc != nullptr);
 
@@ -307,10 +309,12 @@ bool FixtureManager::addFixture(QString manuf, QString model, QString mode, QStr
 
         fxi->setFixtureDefinition(fxiDef, fxiMode);
 
-        m_doc->addFixture(fxi);
-        Tardis::instance()->enqueueAction(Tardis::FixtureCreate, fxi->id(), QVariant(),
-                                          Tardis::instance()->actionToByteArray(Tardis::FixtureCreate, fxi->id()));
-        slotFixtureAdded(fxi->id(), QVector3D(xPos, yPos, 0));
+        if (m_doc->addFixture(fxi) == true)
+        {
+            Tardis::instance()->enqueueAction(Tardis::FixtureCreate, fxi->id(), QVariant(),
+                                              Tardis::instance()->actionToByteArray(Tardis::FixtureCreate, fxi->id()));
+            slotFixtureAdded(fxi->id(), QVector3D(xPos, yPos, 0));
+        }
 
         fxAddress += (channels + gap);
     }
@@ -658,8 +662,8 @@ void FixtureManager::addFixtureNode(Doc *doc, TreeModel *treeModel, Fixture *fix
 
                     if (showFlags & ShowModifier)
                     {
-                        // TODO
-                        chParams.append("");
+                        ChannelModifier *cm = fixture->channelModifier(chIdx);
+                        chParams.append(cm != nullptr ? cm->name() : "");
                     }
 
                     treeModel->addItem(channel->name(), chParams, fxPath, flags);
@@ -840,6 +844,63 @@ QString FixtureManager::fixtureIcon(quint32 fixtureID)
     return fixture->iconResource(true);
 }
 
+QStringList FixtureManager::fixtureModes(quint32 itemID)
+{
+    QStringList modes;
+    quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
+    Fixture *fixture = m_doc->fixture(fixtureID);
+    if (fixture == nullptr)
+        return modes;
+
+    for (QLCFixtureMode *mode : fixture->fixtureDef()->modes())
+        modes.append(mode->name());
+
+    return modes;
+}
+
+int FixtureManager::fixtureModeIndex(quint32 itemID)
+{
+    quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
+    Fixture *fixture = m_doc->fixture(fixtureID);
+    if (fixture == nullptr)
+        return -1;
+
+    QLCFixtureMode *currMode = fixture->fixtureMode();
+    QList<QLCFixtureMode *> modes = fixture->fixtureDef()->modes();
+
+    return modes.indexOf(currMode);
+}
+
+bool FixtureManager::setFixtureModeIndex(quint32 itemID, int index)
+{
+    quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
+    Fixture *fixture = m_doc->fixture(fixtureID);
+    if (fixture == nullptr)
+        return false;
+
+    QList<QLCFixtureMode *> modes = fixture->fixtureDef()->modes();
+    if (index < 0 || index >= modes.count())
+        return false;
+
+    QLCFixtureMode *newMode = modes.at(index);
+
+    // check if new channels are available
+    int chNum = newMode->channels().count();
+
+    for (quint32 i = fixture->universeAddress(); i < fixture->universeAddress() + chNum; i++)
+    {
+        quint32 id = m_doc->fixtureForAddress(i);
+        if (id != fixture->id() && id != Fixture::invalidId())
+            return false;
+    }
+
+    fixture->setFixtureDefinition(fixture->fixtureDef(), newMode);
+
+    emit fixturesMapChanged();
+
+    return true;
+}
+
 int FixtureManager::fixtureIDfromItemID(quint32 itemID)
 {
     return FixtureUtils::itemFixtureID(itemID);
@@ -853,8 +914,8 @@ int FixtureManager::fixtureLinkedIndex(quint32 itemID)
 void FixtureManager::updateLinkedFixtureNode(quint32 itemID, bool add)
 {
     quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
-    int headIndex = FixtureUtils::itemHeadIndex(itemID);
-    int linkedIndex = FixtureUtils::itemLinkedIndex(itemID);
+    quint16 headIndex = FixtureUtils::itemHeadIndex(itemID);
+    quint16 linkedIndex = FixtureUtils::itemLinkedIndex(itemID);
     MonitorProperties *monProps = m_doc->monitorProperties();
     QStringList uniNames = m_doc->inputOutputMap()->universeNames();
 
@@ -1607,17 +1668,6 @@ void FixtureManager::setChannelValue(quint32 fixtureID, quint32 channelIndex, qu
     emit channelValueChanged(fixtureID, channelIndex, value);
 }
 
-void FixtureManager::setIntensityValue(quint8 value)
-{
-    emit channelTypeValueChanged(QLCChannel::Intensity, value);
-}
-
-void FixtureManager::setColorValue(quint8 red, quint8 green, quint8 blue,
-                                   quint8 white, quint8 amber, quint8 uv)
-{
-    emit colorChanged(QColor(red, green, blue), QColor(white, amber, uv));
-}
-
 void FixtureManager::setPresetValue(quint32 fixtureID, int chIndex, quint8 value)
 {
     qDebug() << "[FixtureManager] setPresetValue - fixture:" << fixtureID << ", channel:" << chIndex << "value:" << value;
@@ -1742,7 +1792,7 @@ QMultiHash<int, SceneValue> FixtureManager::getFixtureCapabilities(quint32 itemI
             case QLCChannel::Tilt:
             {
                 hasPosition = true;
-                if(fixture->fixtureMode() != nullptr)
+                if (fixture->fixtureMode() != nullptr)
                 {
                     int panDeg = phy.focusPanMax();
                     int tiltDeg = phy.focusTiltMax();
@@ -2037,3 +2087,77 @@ int FixtureManager::colorsMask() const
     return m_colorsMask;
 }
 
+/*********************************************************************
+ * Channel modifiers
+ *********************************************************************/
+
+QStringList FixtureManager::channelModifiersList() const
+{
+    QList<QString> names = m_doc->modifiersCache()->templateNames();
+    names.sort();
+    names.prepend("None");
+
+    return names;
+}
+
+void FixtureManager::selectChannelModifier(QString name)
+{
+    m_selectedChannelModifier = m_doc->modifiersCache()->modifier(name);
+
+    emit channelModifierValuesChanged();
+}
+
+void FixtureManager::setChannelModifier(quint32 itemID, quint32 channelIndex)
+{
+    quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
+    Fixture *fixture = m_doc->fixture(fixtureID);
+    if (fixture == nullptr)
+        return;
+
+    fixture->setChannelModifier(channelIndex, m_selectedChannelModifier);
+
+    // update UI tree
+    setItemRoleData(itemID, channelIndex, "modifier", m_selectedChannelModifier == nullptr ?
+                    "None" : m_selectedChannelModifier->name());
+}
+
+void FixtureManager::showModifierEditor(quint32 itemID, quint32 channelIndex)
+{
+    quint32 fixtureID = FixtureUtils::itemFixtureID(itemID);
+    Fixture *fixture = m_doc->fixture(fixtureID);
+    if (fixture == nullptr)
+        return;
+
+    ChannelModifier *cm = fixture->channelModifier(channelIndex);
+
+    QQuickItem *fgmItem = qobject_cast<QQuickItem*>(m_view->rootObject()->findChild<QObject *>("fixtureGroupManager"));
+    if (fgmItem == nullptr)
+        return;
+
+    selectChannelModifier(cm == nullptr ? "" : cm->name());
+
+    QMetaObject::invokeMethod(fgmItem, "showChannelModifierEditor",
+            Q_ARG(QVariant, itemID),
+            Q_ARG(QVariant, channelIndex),
+            Q_ARG(QVariant, cm == nullptr ? "" : cm->name()));
+}
+
+QVariantList FixtureManager::channelModifierValues() const
+{
+    QVariantList values;
+
+    if (m_selectedChannelModifier != nullptr)
+    {
+        QList< QPair<uchar, uchar> > map = m_selectedChannelModifier->modifierMap();
+        for (int i = 0; i < map.count(); i++)
+        {
+            QPair<uchar, uchar> dmxPair = map.at(i);
+            values.append(dmxPair.first);
+            values.append(dmxPair.second);
+        }
+    }
+
+    return values;
+}
+
+
