@@ -22,13 +22,10 @@
 #include <QDebug>
 
 #include "audioplugincache.h"
-#include "genericdmxsource.h"
 #include "collectioneditor.h"
 #include "functionmanager.h"
 #include "rgbmatrixeditor.h"
-#include "contextmanager.h"
 #include "treemodelitem.h"
-#include "scriptwrapper.h"
 #include "chasereditor.h"
 #include "scripteditor.h"
 #include "sceneeditor.h"
@@ -40,6 +37,7 @@
 #include "rgbmatrix.h"
 #include "function.h"
 #include "sequence.h"
+#include "script.h"
 #include "chaser.h"
 #include "scene.h"
 #include "audio.h"
@@ -238,7 +236,7 @@ quint32 FunctionManager::addFunctiontoDoc(Function *func, QString name, bool sel
     return Function::invalidId();
 }
 
-quint32 FunctionManager::createFunction(int type, QStringList fileList)
+quint32 FunctionManager::createFunction(int type, QVariantList fixturesList)
 {
     Function* f = nullptr;
     QString name;
@@ -249,6 +247,12 @@ quint32 FunctionManager::createFunction(int type, QStringList fileList)
         {
             f = new Scene(m_doc);
             name = tr("New Scene");
+            if (fixturesList.count())
+            {
+                Scene *scene = qobject_cast<Scene *>(f);
+                for (QVariant fixtureID : fixturesList)
+                    scene->addFixture(fixtureID.toUInt());
+            }
             m_sceneCount++;
             emit sceneCountChanged();
         }
@@ -263,6 +267,13 @@ quint32 FunctionManager::createFunction(int type, QStringList fileList)
                  * that awful effect of playing steps with 0 duration */
                 Chaser *chaser = qobject_cast<Chaser*>(f);
                 chaser->setDuration(1000);
+
+                for (QVariant &fId : m_selectedIDList)
+                {
+                    ChaserStep chs;
+                    chs.fid = fId.toUInt();
+                    chaser->addStep(chs);
+                }
             }
             m_chaserCount++;
             emit chaserCountChanged();
@@ -292,6 +303,19 @@ quint32 FunctionManager::createFunction(int type, QStringList fileList)
         {
             f = new EFX(m_doc);
             name = tr("New EFX");
+            if (fixturesList.count())
+            {
+                EFX *efx = qobject_cast<EFX *>(f);
+                for (QVariant fixtureID : fixturesList)
+                {
+                    Fixture *fixture = m_doc->fixture(fixtureID.toUInt());
+                    if (fixture == nullptr)
+                        continue;
+
+                    for (int headIdx = 0; headIdx < fixture->heads(); headIdx++)
+                        efx->addFixture(fixture->id(), headIdx);
+                }
+            }
             m_efxCount++;
             emit efxCountChanged();
         }
@@ -335,6 +359,20 @@ quint32 FunctionManager::createFunction(int type, QStringList fileList)
             emit showCountChanged();
         }
         break;
+        default:
+        break;
+    }
+
+    return addFunctiontoDoc(f, name, true);
+}
+
+quint32 FunctionManager::createAudioVideoFunction(int type, QStringList fileList)
+{
+    Function* f = nullptr;
+    QString name;
+
+    switch(type)
+    {
         case Function::AudioType:
         {
             name = tr("New Audio");
@@ -399,8 +437,6 @@ quint32 FunctionManager::createFunction(int type, QStringList fileList)
             }
         }
         break;
-        default:
-        break;
     }
 
     return addFunctiontoDoc(f, name, true);
@@ -441,13 +477,18 @@ QString FunctionManager::functionPath(quint32 id)
 
 void FunctionManager::clearTree()
 {
-    setPreview(false);
+    setPreviewEnabled(false);
     m_selectedIDList.clear();
     m_selectedFolderList.clear();
     m_functionTree->clear();
 }
 
-void FunctionManager::setPreview(bool enable)
+bool FunctionManager::previewEnabled() const
+{
+    return m_previewEnabled;
+}
+
+void FunctionManager::setPreviewEnabled(bool enable)
 {
     if (m_currentEditor != nullptr)
     {
@@ -463,14 +504,13 @@ void FunctionManager::setPreview(bool enable)
                 if (enable == false)
                     f->stop(FunctionParent::master());
                 else
-                {
                     f->start(m_doc->masterTimer(), FunctionParent::master());
-                }
             }
         }
     }
 
     m_previewEnabled = enable;
+    emit previewEnabledChanged();
 }
 
 void FunctionManager::selectFunctionID(quint32 fID, bool multiSelection)
@@ -811,6 +851,19 @@ void FunctionManager::deleteEditorItems(QVariantList list)
         m_currentEditor->deleteItems(list);
 }
 
+void FunctionManager::deleteSequenceFixtures(QVariantList list)
+{
+    if (m_sceneEditor == nullptr)
+        return;
+
+    // First remove fixtures from the Sequence steps
+    ChaserEditor *chaserEditor = qobject_cast<ChaserEditor*>(m_currentEditor);
+    chaserEditor->removeFixtures(list);
+
+    // Then delete the fixtures from the Scene
+    m_sceneEditor->deleteItems(list);
+}
+
 void FunctionManager::renameSelectedItems(QString newName, bool numbering, int startNumber, int digits)
 {
     if (m_selectedIDList.isEmpty() && m_selectedFolderList.isEmpty())
@@ -1098,7 +1151,7 @@ void FunctionManager::dumpOnNewScene(QList<SceneValue> dumpValues, QList<quint32
 
     if (m_doc->addFunction(newScene) == true)
     {
-        setPreview(false);
+        setPreviewEnabled(false);
         Tardis::instance()->enqueueAction(Tardis::FunctionCreate, newScene->id(), QVariant(),
                                           Tardis::instance()->actionToByteArray(Tardis::FunctionCreate, newScene->id()));
     }
@@ -1279,7 +1332,7 @@ void FunctionManager::updateFunctionsTree()
 
 void FunctionManager::slotDocLoaded()
 {
-    setPreview(false);
+    setPreviewEnabled(false);
     updateFunctionsTree();
 }
 
