@@ -225,7 +225,10 @@ void MainView3D::setUniverseFilter(quint32 universeFilter)
         if (fixture == nullptr)
             return;
 
-        SceneItem *meshRef = m_entitiesMap.value(itemID);
+        SceneItem *meshRef = m_entitiesMap.value(itemID, nullptr);
+
+        if (meshRef == nullptr || meshRef->m_rootItem == nullptr)
+            continue;
 
         if (universeFilter == Universe::invalid() || fixture->universe() == (quint32)universeFilter)
         {
@@ -1175,7 +1178,7 @@ void MainView3D::updateFixtureItem(Fixture *fixture, quint16 headIndex, quint16
             break;
             case QLCChannel::Speed:
             {
-                if (previous.count() && value == uchar(previous.at(i)))
+                if (previous.length() && value == uchar(previous.at(i)))
                     break;
 
                 int panSpeed, tiltSpeed;
@@ -1211,7 +1214,7 @@ void MainView3D::updateFixtureItem(Fixture *fixture, quint16 headIndex, quint16
             break;
             case QLCChannel::Beam:
             {
-                if (previous.count() && value == uchar(previous.at(i)))
+                if (previous.length() && value == uchar(previous.at(i)))
                     break;
 
                 switch (ch->preset())
@@ -1229,7 +1232,7 @@ void MainView3D::updateFixtureItem(Fixture *fixture, quint16 headIndex, quint16
             break;
             case QLCChannel::Gobo:
             {
-                if (previous.count() && value == uchar(previous.at(i)))
+                if (previous.length() && value == uchar(previous.at(i)))
                     break;
 
                 QLCCapability *cap = ch->searchCapability(value);
@@ -1273,7 +1276,7 @@ void MainView3D::updateFixtureItem(Fixture *fixture, quint16 headIndex, quint16
             break;
             case QLCChannel::Shutter:
             {
-                if (previous.count() && value == uchar(previous.at(i)))
+                if (previous.length() && value == uchar(previous.at(i)))
                     break;
 
                 int high = 200, low = 800;
@@ -1304,9 +1307,12 @@ void MainView3D::updateFixtureSelection(QList<quint32> fixtures)
     {
         it.next();
         quint32 fxID = it.key();
-        SceneItem *meshRef = m_entitiesMap.value(fxID);
+        SceneItem *meshRef = m_entitiesMap.value(fxID, nullptr);
 
-        if(fixtures.contains(fxID))
+        if (meshRef == nullptr || meshRef->m_rootItem == nullptr)
+            return;
+
+        if (fixtures.contains(fxID))
         {
             meshRef->m_rootItem->setProperty("isSelected", true);
             meshRef->m_selectionBox->setProperty("isSelected", true);
@@ -1324,7 +1330,7 @@ void MainView3D::updateFixtureSelection(quint32 itemID, bool enable)
     qDebug() << "[View3D] item" << itemID << "selected:" << enable;
 
     SceneItem *meshRef = m_entitiesMap.value(itemID, nullptr);
-    if (meshRef)
+    if (meshRef && meshRef->m_rootItem)
     {
         meshRef->m_rootItem->setProperty("isSelected", enable);
         meshRef->m_selectionBox->setProperty("isSelected", enable);
