@@ -147,7 +147,7 @@ void SceneEditor::registerFixtureConsole(int index, QQuickItem *item)
     QVariantList dmxValues;
     QByteArray values = m_channelsCache[fixtureID];
 
-    for (int i = 0; i < values.count(); i++)
+    for (int i = 0; i < values.length(); i++)
         dmxValues.append(QString::number((uchar)values.at(i)));
 
     item->setProperty("values", QVariant::fromValue(dmxValues));
@@ -194,17 +194,22 @@ void SceneEditor::slotSceneValueChanged(SceneValue scv)
     {
         connect(fixture, SIGNAL(aliasChanged()), this, SLOT(slotAliasChanged()));
 
+        // Add the fixture to the side panel list
         QVariantMap fxMap;
         fxMap.insert("cRef", QVariant::fromValue(fixture));
         fxMap.insert("isSelected", false);
         m_fixtureList->addDataMap(fxMap);
         m_fixtureIDs.append(scv.fxi);
+
+        // update the fixture list for the UI
         updateLists();
     }
 
+    // update the channel values cache
+    setCacheChannelValue(scv);
+
     if (m_sceneConsole)
     {
-
         if (m_fxConsoleMap.contains(fxIndex))
         {
             QMetaObject::invokeMethod(m_fxConsoleMap[fxIndex], "setChannelValue",
@@ -272,13 +277,16 @@ void SceneEditor::addComponent(int type, quint32 id)
         break;
         case App::FixtureGroupDragItem:
             m_scene->addFixtureGroup(id);
+            m_doc->setModified();
         break;
         case App::FixtureDragItem:
             m_scene->addFixture(id);
+            m_doc->setModified();
         break;
         case App::PaletteDragItem:
         {
             m_scene->addPalette(id);
+            m_doc->setModified();
         }
         break;
         default:
@@ -290,7 +298,7 @@ void SceneEditor::addComponent(int type, quint32 id)
 
 void SceneEditor::deleteItems(QVariantList list)
 {
-    if (m_scene == nullptr)
+    if (m_scene == nullptr || list.isEmpty())
         return;
 
     for (QVariant vIdx : list)
@@ -304,9 +312,15 @@ void SceneEditor::deleteItems(QVariantList list)
             case App::FixtureDragItem:
             {
                 Fixture *fixture = dataMap["cRef"].value<Fixture *>();
-                qDebug() << "removing fixture with ID" << fixture->id();
+                quint32 fixtureID = fixture->id();
+                qDebug() << "removing fixture with ID" << fixtureID;
                 // TODO: tardis
-                m_scene->removeFixture(fixture->id());
+                for (SceneValue &scv : m_scene->values())
+                {
+                    if (scv.fxi == fixtureID)
+                        m_scene->unsetValue(fixtureID, scv.channel);
+                }
+                m_scene->removeFixture(fixtureID);
             }
             break;
             case App::FixtureGroupDragItem:
@@ -328,6 +342,8 @@ void SceneEditor::deleteItems(QVariantList list)
         }
     }
 
+    m_doc->setModified();
+
     updateLists();
 }
 
