@@ -200,6 +200,9 @@ void Tardis::redoAction()
 void Tardis::resetHistory()
 {
     m_history.clear();
+    m_historyIndex = -1;
+    m_historyCount = 0;
+    m_busy = false;
 }
 
 void Tardis::forwardActionToNetwork(int code, TardisAction &action)
@@ -921,6 +924,13 @@ int Tardis::processAction(TardisAction &action, bool undo)
         }
         break;
 
+        case AudioSetVolume:
+        {
+            auto member = std::mem_fn(&Audio::setVolume);
+            member(qobject_cast<Audio *>(m_doc->function(action.m_objID)), value->toDouble());
+        }
+        break;
+
         /* *********************** Video editing actions *********************** */
 
         case VideoSetSource:
