@@ -100,6 +100,9 @@ public:
     /** @reimp */
     void adjustFunctionIntensity(Function *f, qreal value);
 
+    /** @reimp */
+    void adjustIntensity(qreal val);
+
     /**
      *  The actual method used to request a change of state of this
      *  Button. Depending on the action type this will start/stop
@@ -173,7 +176,7 @@ public:
     static ButtonAction stringToAction(const QString& str);
 
     void setStopAllFadeOutTime(int ms);
-    int stopAllFadeOutTime();
+    int stopAllFadeOutTime() const;
 
 signals:
     void actionTypeChanged(ButtonAction actionType);
@@ -210,6 +213,10 @@ protected:
     /*********************************************************************
      * External input
      *********************************************************************/
+public:
+    /** @reimp */
+    void updateFeedback();
+
 public slots:
     /** @reimp */
     void slotInputValueChanged(quint8 id, uchar value);
