@@ -62,6 +62,11 @@ VCCueList::VCCueList(Doc *doc, QObject *parent)
     m_stepsList->setRoleNames(listRoles);
 
     connect(m_timer, SIGNAL(timeout()), this, SLOT(slotProgressTimeout()));
+
+    connect(m_doc, SIGNAL(functionRemoved(quint32)),
+            this, SLOT(slotFunctionRemoved(quint32)));
+    connect(m_doc, SIGNAL(functionNameChanged(quint32)),
+            this, SLOT(slotFunctionNameChanged(quint32)));
 }
 
 VCCueList::~VCCueList()
@@ -411,6 +416,22 @@ void VCCueList::addFunctions(QVariantList idsList, int insertIndex)
     }
 }
 
+void VCCueList::setStepNote(int index, QString text)
+{
+    Chaser *ch = chaser();
+    if (ch == nullptr)
+        return;
+
+    ChaserStep *step = ch->stepAt(index);
+    if (step == nullptr)
+        return;
+
+    step->note = text;
+
+    QModelIndex mIdx = m_stepsList->index(index, 0, QModelIndex());
+    m_stepsList->setDataWithRole(mIdx, "note", text);
+}
+
 quint32 VCCueList::chaserID() const
 {
     return m_chaserID;
@@ -435,8 +456,10 @@ void VCCueList::setChaserID(quint32 fid)
                    this, SLOT(slotFunctionStopped(quint32)));
         disconnect(current, SIGNAL(currentStepChanged(int)),
                    this, SLOT(slotCurrentStepChanged(int)));
+        connect(current, SIGNAL(stepChanged(int)),
+                this, SLOT(slotStepChanged(int)));
 
-        if(current->isRunning())
+        if (current->isRunning())
         {
             running = true;
             current->stop(functionParent());
@@ -462,6 +485,8 @@ void VCCueList::setChaserID(quint32 fid)
                 this, SLOT(slotFunctionStopped(quint32)));
         connect(function, SIGNAL(currentStepChanged(int)),
                 this, SLOT(slotCurrentStepChanged(int)));
+        connect(function, SIGNAL(stepChanged(int)),
+                this, SLOT(slotStepChanged(int)));
 
         emit chaserIDChanged(fid);
     }
@@ -480,6 +505,30 @@ void VCCueList::setChaserID(quint32 fid)
                                       function ? function->id() : Function::invalidId());
 }
 
+void VCCueList::slotFunctionRemoved(quint32 fid)
+{
+    if (fid == m_chaserID)
+    {
+        m_chaserID = Function::invalidId();
+        m_stepsList->clear();
+        emit chaserIDChanged(-1);
+
+        resetIntensityOverrideAttribute();
+    }
+}
+
+void VCCueList::slotStepChanged(int index)
+{
+    ChaserStep *step = chaser()->stepAt(index);
+    ChaserEditor::updateStepInListModel(m_doc, chaser(), m_stepsList, step, index);
+}
+
+void VCCueList::slotFunctionNameChanged(quint32 fid)
+{
+    if (fid == m_chaserID)
+        emit chaserIDChanged(fid);
+}
+
 /*********************************************************************
  * Playback
  *********************************************************************/
@@ -597,6 +646,21 @@ void VCCueList::stopChaser()
     emit playbackStatusChanged();
 }
 
+/*********************************************************************
+ * External input
+ *********************************************************************/
+
+void VCCueList::updateFeedback()
+{
+    sendFeedback(m_sideFaderLevel, INPUT_SIDE_FADER_ID, VCWidget::ExactValue);
+
+    Chaser *ch = chaser();
+    if (ch == NULL)
+        return;
+
+    sendFeedback(ch->isRunning() ? UCHAR_MAX : 0, INPUT_PLAY_PAUSE_ID, VCWidget::ExactValue);
+}
+
 void VCCueList::slotInputValueChanged(quint8 id, uchar value)
 {
     switch(id)
@@ -775,6 +839,29 @@ void VCCueList::nextClicked()
     }
 }
 
+void VCCueList::playCurrentStep()
+{
+    Chaser *ch = chaser();
+    if (ch == nullptr)
+        return;
+
+    if (ch->isRunning())
+    {
+        ChaserAction action;
+        action.m_action = ChaserSetStepIndex;
+        action.m_stepIndex = m_playbackIndex;
+        action.m_masterIntensity = intensity();
+        action.m_stepIntensity = getPrimaryIntensity();
+        action.m_fadeMode = getFadeMode();
+        ch->setAction(action);
+    }
+    else
+    {
+        startChaser(m_playbackIndex == -1 ? 0 : m_playbackIndex);
+    }
+
+}
+
 void VCCueList::slotFunctionRunning(quint32 fid)
 {
     if (fid == m_chaserID)
@@ -984,6 +1071,7 @@ bool VCCueList::saveXML(QXmlStreamWriter *doc)
     saveXMLInputControl(doc, INPUT_PREVIOUS_STEP_ID, KXMLQLCVCCueListPrevious);
     saveXMLInputControl(doc, INPUT_PLAY_PAUSE_ID, KXMLQLCVCCueListPlayback);
     saveXMLInputControl(doc, INPUT_STOP_PAUSE_ID, KXMLQLCVCCueListStop);
+    saveXMLInputControl(doc, INPUT_SIDE_FADER_ID, KXMLQLCVCCueListCrossfadeLeft);
 
     /* End the <CueList> tag */
     doc->writeEndElement();
