@@ -182,6 +182,13 @@ public:
 
     Q_INVOKABLE void addFunctions(QVariantList idsList, int insertIndex = -1);
 
+    Q_INVOKABLE void setStepNote(int index, QString text);
+
+private slots:
+    void slotFunctionRemoved(quint32 fid);
+    void slotFunctionNameChanged(quint32 fid);
+    void slotStepChanged(int index);
+
 private:
     FunctionParent functionParent() const;
 
@@ -229,6 +236,7 @@ public:
     Q_INVOKABLE void stopClicked();
     Q_INVOKABLE void previousClicked();
     Q_INVOKABLE void nextClicked();
+    Q_INVOKABLE void playCurrentStep();
 
 signals:
     void playbackStatusChanged();
@@ -275,6 +283,10 @@ private:
     /*********************************************************************
      * External input
      *********************************************************************/
+public:
+    /** @reimp */
+    void updateFeedback();
+
 public slots:
     /** @reimp */
     void slotInputValueChanged(quint8 id, uchar value);
