@@ -64,9 +64,9 @@ VCSlider::VCSlider(Doc *doc, QObject *parent)
     , m_controlledAttributeId(Function::invalidAttributeId())
     , m_attributeMinValue(0)
     , m_attributeMaxValue(UCHAR_MAX)
-    , m_priorityRequest(-1)
 {
     setType(VCWidget::SliderWidget);
+    setSliderMode(Adjust);
 
     registerExternalControl(INPUT_SLIDER_CONTROL_ID, tr("Slider Control"), false);
     registerExternalControl(INPUT_SLIDER_RESET_ID, tr("Reset Control"), false);
@@ -80,12 +80,7 @@ VCSlider::~VCSlider()
     m_doc->masterTimer()->unregisterDMXSource(this);
 
     // request to delete all the active faders
-    foreach (QSharedPointer<GenericFader> fader, m_fadersMap.values())
-    {
-        if (!fader.isNull())
-            fader->requestDelete();
-    }
-    m_fadersMap.clear();
+    removeActiveFaders();
 
     if (m_item)
         delete m_item;
@@ -255,12 +250,7 @@ void VCSlider::setSliderMode(SliderMode mode)
         m_doc->masterTimer()->unregisterDMXSource(this);
 
         // request to delete all the active faders
-        foreach (QSharedPointer<GenericFader> fader, m_fadersMap.values())
-        {
-            if (!fader.isNull())
-                fader->requestDelete();
-        }
-        m_fadersMap.clear();
+        removeActiveFaders();
     }
 }
 
@@ -404,7 +394,6 @@ void VCSlider::setValue(int value, bool setDMX, bool updateFeedback)
         case Level:
             if (m_monitorEnabled == true && m_isOverriding == false && setDMX)
             {
-                m_priorityRequest = Universe::Override;
                 m_isOverriding = true;
                 emit isOverridingChanged();
             }
@@ -430,16 +419,7 @@ void VCSlider::setValue(int value, bool setDMX, bool updateFeedback)
         m_levelValueChanged = true;
 
     if (updateFeedback)
-    {
-        int fbv = 0;
-        if (invertedAppearance() == true)
-            fbv = rangeHighLimit() - m_value;
-        else
-            fbv = m_value;
-        fbv = (int)SCALE(float(fbv), float(rangeLowLimit()),
-                         float(rangeHighLimit()), float(0), float(UCHAR_MAX));
-        sendFeedback(fbv, INPUT_SLIDER_CONTROL_ID);
-    }
+        this->updateFeedback();
 }
 
 void VCSlider::setRangeLowLimit(qreal value)
@@ -482,7 +462,6 @@ void VCSlider::setMonitorEnabled(bool enable)
         return;
 
     m_monitorEnabled = enable;
-    m_priorityRequest = Universe::Override;
 
     emit monitorEnabledChanged();
 }
@@ -504,11 +483,19 @@ bool VCSlider::isOverriding() const
 
 void VCSlider::setIsOverriding(bool enable)
 {
-    if (enable == m_isOverriding)
-        return;
-
     if (enable == false && m_monitorEnabled)
-        setValue(m_monitorValue, false, false);
+    {
+        if (m_isOverriding)
+        {
+            removeActiveFaders();
+            setValue(m_monitorValue, false, false);
+        }
+        else
+        {
+            // reset once more
+            //setValue(0, true, true);
+        }
+    }
 
     m_isOverriding = enable;
     emit isOverridingChanged();
@@ -587,6 +574,16 @@ void VCSlider::setSearchFilter(QString searchFilter)
     emit searchFilterChanged();
 }
 
+void VCSlider::removeActiveFaders()
+{
+    foreach (QSharedPointer<GenericFader> fader, m_fadersMap.values())
+    {
+        if (!fader.isNull())
+            fader->requestDelete();
+    }
+    m_fadersMap.clear();
+}
+
 void VCSlider::slotTreeDataChanged(TreeModelItem *item, int role, const QVariant &value)
 {
     qDebug() << "Slider tree data changed" << value.toInt();
@@ -828,7 +825,7 @@ void VCSlider::setControlledFunction(quint32 fid)
         if ((isEditing() && caption().isEmpty()) || caption() == defaultCaption())
             setCaption(function->name());
 
-        if(running)
+        if (running)
             function->start(m_doc->masterTimer(), functionParent());
 
         emit controlledFunctionChanged(fid);
@@ -859,6 +856,11 @@ void VCSlider::adjustIntensity(qreal val)
         qreal fraction = sliderValueToAttributeValue(m_value);
         adjustFunctionAttribute(function, fraction * intensity());
     }
+    else if (sliderMode() == Level)
+    {
+        // force channel levels refresh
+        m_levelValueChanged = true;
+    }
 }
 
 void VCSlider::slotControlledFunctionAttributeChanged(int attrIndex, qreal fraction)
@@ -1088,6 +1090,7 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
         // have the same value. If so, move the widget slider or knob
         // to the detected position
         if (mixedDMXlevels == false &&
+            monitorSliderValue != -1 &&
             monitorSliderValue != m_monitorValue)
         {
             //qDebug() << caption() << "Monitor DMX value:" << monitorSliderValue << "level value:" << m_value;
@@ -1116,7 +1119,7 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
             QSharedPointer<GenericFader> fader = m_fadersMap.value(universe, QSharedPointer<GenericFader>(nullptr));
             if (fader.isNull())
             {
-                fader = universes[universe]->requestFader();
+                fader = universes[universe]->requestFader(m_monitorEnabled ? Universe::Override : Universe::Auto);
                 m_fadersMap[universe] = fader;
             }
 
@@ -1131,10 +1134,7 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
 
             // on override, force channel to LTP
             if (m_isOverriding)
-            {
-                fc->removeFlag(FadeChannel::HTP);
-                fc->addFlag(FadeChannel::LTP);
-            }
+                fc->addFlag(FadeChannel::Override);
 
             if (chType & FadeChannel::Intensity && clickAndGoType() == CnGColors)
             {
@@ -1159,7 +1159,7 @@ void VCSlider::writeDMXLevel(MasterTimer* timer, QList<Universe *> universes)
             }
 
             fc->setStart(fc->current());
-            fc->setTarget(modLevel * intensity());
+            fc->setTarget(qreal(modLevel) * intensity());
             fc->setReady(false);
             fc->setElapsed(0);
         }
@@ -1222,12 +1222,27 @@ void VCSlider::writeDMXAdjust(MasterTimer* timer, QList<Universe *> ua)
  * External input
  *********************************************************************/
 
+void VCSlider::updateFeedback()
+{
+    int fbv = invertedAppearance() ? rangeHighLimit() - m_value : m_value;
+    fbv = int(SCALE(float(fbv), float(rangeLowLimit()),
+                    float(rangeHighLimit()), float(0), float(UCHAR_MAX)));
+
+    sendFeedback(fbv, INPUT_SLIDER_CONTROL_ID);
+}
+
 void VCSlider::slotInputValueChanged(quint8 id, uchar value)
 {
-    if (id != INPUT_SLIDER_CONTROL_ID)
-        return;
-
-    setValue(value, true, false);
+    switch (id)
+    {
+        case INPUT_SLIDER_CONTROL_ID:
+            setValue(value, true, false);
+        break;
+        case INPUT_SLIDER_RESET_ID:
+            if (value)
+                setIsOverriding(false);
+        break;
+    }
 }
 
 /*********************************************************************
@@ -1243,6 +1258,7 @@ bool VCSlider::loadXML(QXmlStreamReader &root)
     }
 
     QString str;
+    bool enableMonitoring = false;
 
     /* Widget commons */
     loadXMLCommon(root);
@@ -1291,10 +1307,8 @@ bool VCSlider::loadXML(QXmlStreamReader &root)
 
             if (mAttrs.hasAttribute(KXMLQLCVCSliderLevelMonitor))
             {
-                if (mAttrs.value(KXMLQLCVCSliderLevelMonitor).toString() == "false")
-                    setMonitorEnabled(false);
-                else
-                    setMonitorEnabled(true);
+                if (mAttrs.value(KXMLQLCVCSliderLevelMonitor).toString() != "false")
+                    enableMonitoring = true;
             }
         }
         else if (root.name() == KXMLQLCVCSliderOverrideReset)
@@ -1320,6 +1334,8 @@ bool VCSlider::loadXML(QXmlStreamReader &root)
         }
     }
 
+    setMonitorEnabled(enableMonitoring);
+
     if (clickAndGoType() == CnGPreset)
     {
         updateClickAndGoResource();
@@ -1502,7 +1518,10 @@ bool VCSlider::saveXML(QXmlStreamWriter *doc)
     /* Level high limit */
     doc->writeAttribute(KXMLQLCVCSliderLevelHighLimit, QString::number(rangeHighLimit()));
     /* Level value */
-    doc->writeAttribute(KXMLQLCVCSliderLevelValue, QString::number(value()));
+    if (monitorEnabled())
+        doc->writeAttribute(KXMLQLCVCSliderLevelValue, QString::number(0));
+    else
+        doc->writeAttribute(KXMLQLCVCSliderLevelValue, QString::number(value()));
 
     /* Level channels */
     for (SceneValue scv : m_levelChannels)
