@@ -280,6 +280,9 @@ public:
     QString searchFilter() const;
     void setSearchFilter(QString searchFilter);
 
+private:
+    void removeActiveFaders();
+
 protected slots:
     void slotTreeDataChanged(TreeModelItem *item, int role, const QVariant &value);
 
@@ -439,11 +442,14 @@ protected:
 private:
     /** Map used to lookup a GenericFader instance for a Universe ID */
     QMap<quint32, QSharedPointer<GenericFader> > m_fadersMap;
-    int m_priorityRequest;
 
     /*********************************************************************
      * External input
      *********************************************************************/
+public:
+    /** @reimp */
+    void updateFeedback();
+
 public slots:
     /** @reimp */
     void slotInputValueChanged(quint8 id, uchar value);
