@@ -112,6 +112,8 @@ qreal VirtualConsole::pixelDensity() const
 
 void VirtualConsole::resetContents()
 {
+    resetWidgetSelection();
+
     foreach (VCPage *page, m_pages)
     {
         page->deleteChildren();
@@ -841,6 +843,10 @@ void VirtualConsole::pasteFromClipboard()
         if (cWidget == nullptr)
             continue;
 
+        // do not allow pasting an item into itself
+        if (cWidget->id() == frame->id())
+            continue;
+
         VCWidget *copy = cWidget->createCopy(frame);
         frame->addWidget(renderParent, copy, currPos);
 
@@ -1015,8 +1021,15 @@ void VirtualConsole::handleKeyEvent(QKeyEvent *e, bool pressed)
         if (e->isAutoRepeat())
             return;
 
-        for(VCPage *page : m_pages) // C++11
-            page->handleKeyEvent(e, pressed);
+        int pageIdx = 0;
+
+        for (VCPage *page : m_pages) // C++11
+        {
+            if (pageIdx == selectedPage())
+                page->handleKeyEvent(e, pressed);
+
+            pageIdx++;
+        }
     }
     else
     {
@@ -1124,10 +1137,17 @@ void VirtualConsole::slotInputValueChanged(quint32 universe, quint32 channel, uc
     qDebug() << "Input signal received. Universe:" << universe << ", channel:" << channel << ", value:" << value;
     if (m_inputDetectionEnabled == false)
     {
-        for(VCPage *page : m_pages) // C++11
+        int pageIdx = 0;
+
+        for (VCPage *page : m_pages) // C++11
         {
-            // TODO: send only to enabled (visible) pages
-            page->inputValueChanged(universe, channel, value);
+            if (pageIdx == selectedPage())
+            {
+                page->inputValueChanged(universe, channel, value);
+                break;
+            }
+
+            pageIdx++;
         }
     }
     else
@@ -1138,7 +1158,7 @@ void VirtualConsole::slotInputValueChanged(quint32 universe, quint32 channel, uc
 
         m_autoDetectionWidget->updateInputSource(m_autoDetectionSource, universe, channel);
 
-        for(VCPage *page : m_pages) // C++11
+        for (VCPage *page : m_pages) // C++11
             page->mapInputSource(m_autoDetectionSource, m_autoDetectionWidget, true);
 
         /** At last, disable the autodetection process */
@@ -1178,6 +1198,8 @@ bool VirtualConsole::loadXML(QXmlStreamReader &root)
             m_pages.at(currPageIdx)->loadXML(root);
             if (m_pages.at(currPageIdx)->caption().isEmpty())
                 m_pages.at(currPageIdx)->setCaption(tr("Page %1").arg(currPageIdx + 1));
+
+            m_pages.at(currPageIdx)->buildKeySequenceMap();
             currPageIdx++;
 
         }
@@ -1193,6 +1215,10 @@ bool VirtualConsole::loadXML(QXmlStreamReader &root)
         }
     }
 
+    // delete the exceeding pages
+    while (m_pages.count() - currPageIdx > 0)
+        deletePage(m_pages.count() - 1);
+
     m_loadStatus = Loaded;
 
     return true;
