@@ -59,7 +59,7 @@ var testAlgo;
   colorPalette.makeSubArray = function(_index) {
     var _array = new Array();
     for (var i = 0; i < colorPalette.collection.length; i++) {
-      _array.push(colorPalette.collection[parseInt(i)][parseInt(_index)]);
+      _array.push(colorPalette.collection[parseInt(i, 10)][parseInt(_index, 10)]);
     }
     return _array;
   };
@@ -100,16 +100,16 @@ var testAlgo;
     if (_index >= colorPalette.collection.length) {
       _index = (colorPalette.collection.length - 1);
     }
-    return colorPalette.collection[parseInt(_index)][0];
+    return colorPalette.collection[parseInt(_index, 10)][0];
   };
   algo.getColorValue = function(_index) {
     if (_index < 0) {
       _index = 0;
     }
-    if (_index >= colorPalette.collection.length) {
+    else if (_index >= colorPalette.collection.length) {
       _index = (colorPalette.collection.length - 1);
     }
-    return colorPalette.collection[parseInt(_index)][1];
+    return colorPalette.collection[parseInt(_index, 10)][1];
   };
 
   algo.setColor1Index = function(_name) {
@@ -134,12 +134,14 @@ var testAlgo;
 
   algo.align = 0;
   algo.properties.push("name:align|type:list|" +
-    "display:Align (for even width)|values:Left,Centered|" +
+    "display:Align (for even width)|values:Left,Centered,Split|" +
     "write:setAlign|read:getAlign");
   // Left aligned is default.
   algo.setAlign = function(_align) {
     if (_align === "Centered") {
       algo.align = 1;
+    } else if (_align === "Split") {
+      algo.align = 2;
     } else {
       algo.align = 0;
     }
@@ -147,6 +149,8 @@ var testAlgo;
   algo.getAlign = function() {
     if (algo.align === 1) {
       return "Centered";
+    } else if (algo.align === 2) {
+      return "Split";
     } else {
       return "Left";
     }
@@ -166,7 +170,7 @@ var testAlgo;
     }
   };
   algo.getOrientation = function() {
-    if (parseInt(algo.orientation) === 1) {
+    if (parseInt(algo.orientation, 10) === 1) {
       return "Vertical";
     } else if (algo.orientation === 2) {
       return "Interleaved";
@@ -177,11 +181,11 @@ var testAlgo;
 
   algo.blockSize = 1;
   algo.properties.push("name:blockSize|type:range|"
-    + "display:Block Size (1-16)|"
-    + "values:1,16|"
+    + "display:Block Size / Split (>= 1)|"
+    + "values:1,32000|"
     + "write:setBlockSize|read:getBlockSize");
   algo.setBlockSize = function(_size) {
-    algo.blockSize = parseInt(_size);
+    algo.blockSize = parseInt(_size, 10);
   };
   algo.getBlockSize = function() {
     return algo.blockSize;
@@ -189,11 +193,11 @@ var testAlgo;
 
   algo.offset = 0;
   algo.properties.push("name:offset|type:range|"
-    + "display:Offset (0-16)|"
-    + "values:0,16|"
+    + "display:Offset (>= 0)|"
+    + "values:0,32000|"
     + "write:setOffset|read:getOffset");
   algo.setOffset = function(_size) {
-    algo.offset = parseInt(_size);
+    algo.offset = parseInt(_size, 10);
   };
   algo.getOffset = function() {
     return algo.offset;
@@ -201,60 +205,131 @@ var testAlgo;
 
   algo.rgbMap = function(width, height, rgb, step) {
     var map = new Array(height);
-    var effectiveStep = step;
     var colorSelectOne = (step === 1) ? false : true;
     var rowColorOne = colorSelectOne;
+    var realBlockSize = algo.blockSize;
+
+    for (y = 0; y < height; y++) {
+      map[parseInt(y, 10)] = new Array(width);
+      for (x = 0; x < width; x++) {
+        map[parseInt(y, 10)][parseInt(x, 10)] = 0;
+      }
+    }
 
     var xMax = width;
-    if (algo.align === 1 && width % 2 === 0) {
-      xMax = width / 2 + width % 2;
+    var yMax = height;
+    if (algo.align === 1) {
+      if (algo.orientation === 0 || algo.orientation === 2) {
+        // Centered mode
+        xMax = Math.ceil(width / 2);
+      }
+      if (algo.orientation === 1 || algo.orientation === 2) {
+        // Centered mode
+        yMax = Math.ceil(height / 2);
+      }
     }
-    for (y = 0; y < height; y++) {
+
+    if (algo.align === 2) {
+      // Split mode
       if (algo.orientation === 0) {
+        // Horizontal
+        realBlockSize = width / algo.blockSize;
+      } else if (algo.orientation === 1) {
+        // Vertical
+        realBlockSize = height / algo.blockSize;
+      } else if (algo.orientation === 2) {
+        // Interleaved
+        realBlockSize = Math.min(width, height) / algo.blockSize;
+      }
+    }
+
+    var effectiveStep;
+    var realBlockCount;
+    var lowRest;
+    var highRest;
+    var rest;
+    for (y = 0; y < yMax; y++) {
+      if (algo.orientation === 0) {
+        // Horizontal split; vertical lines
         // Initialize vertical bars, each column the same
         colorSelectOne = (step === 1) ? false : true;
       } else if (algo.orientation === 1) {
         // Horizontal Bars, count steps by row
-        effectiveStep = y + step * algo.blockSize + algo.offset;
+        effectiveStep = y + Math.round(step * realBlockSize) + algo.offset;
+
         // Initialize start color for each row.
-        if (effectiveStep % algo.blockSize === 0) {
+        realBlockCount = Math.floor(effectiveStep / realBlockSize);
+        lowRest = effectiveStep - realBlockCount * realBlockSize;
+        highRest = (realBlockCount + 1) * realBlockSize - effectiveStep;
+        rest = Math.min(lowRest, highRest);
+        if (rest < 0.5 || lowRest === 0.5) {
           colorSelectOne = !colorSelectOne;
         }
       } else if (algo.orientation === 2) {
-        var effectiveY = y + step * algo.blockSize + algo.offset;
-        if (effectiveY % (algo.blockSize) === 0) {
+        // Interleaved
+        var effectiveY = y + Math.floor(step * realBlockSize) + algo.offset;
+
+        realBlockCount = Math.floor(effectiveY / realBlockSize);
+        lowRest = effectiveY - realBlockCount * realBlockSize;
+        highRest = (realBlockCount + 1) * realBlockSize - effectiveY;
+        rest = Math.min(lowRest, highRest);
+        if (rest < 0.5 || lowRest === 0.5) {
           rowColorOne = !rowColorOne;
         }
         colorSelectOne = rowColorOne;
       }
-      map[parseInt(y)] = new Array();
-      for (x = 0; x < width; x++) {
+
+      for (x = 0; x < xMax; x++) {
         if (algo.orientation === 0) {
-          // Vertical bars, count steps by column
+          // Horizontal split, vertical bars, count steps by column
           effectiveStep = x + algo.offset;
-          if (effectiveStep % algo.blockSize === 0) {
+          realBlockCount = Math.floor(effectiveStep / realBlockSize);
+          lowRest = effectiveStep - realBlockCount * realBlockSize;
+          highRest = (realBlockCount + 1) * realBlockSize - effectiveStep;
+          rest = Math.min(lowRest, highRest);
+          if (rest < 0.5 || lowRest == 0.5) {
             colorSelectOne = !colorSelectOne;
           }
         } else if (algo.orientation === 2) {
-          // Horizontal Bars, count steps by row and column
-          var effectiveX = x + step * algo.blockSize + algo.offset;
+          // vertical split, horizontal Bars, count steps by row and column
+          var effectiveX = x + Math.floor(step * realBlockSize) + algo.offset;
           // Change color each step.
-          if (effectiveX % algo.blockSize === 0) {
+          realBlockCount = Math.floor(effectiveX / realBlockSize);
+          lowRest = effectiveX - realBlockCount * realBlockSize;
+          highRest = (realBlockCount + 1) * realBlockSize - effectiveX;
+          rest = Math.min(lowRest, highRest);
+          if (rest < 0.5 || lowRest == 0.5) {
             colorSelectOne = !colorSelectOne;
           }
         }
         if (colorSelectOne) {
-          map[parseInt(y)][parseInt(x)] = algo.getColor1Value();
+          map[parseInt(y, 10)][parseInt(x, 10)] = algo.getColor1Value();
         } else {
-          map[parseInt(y)][parseInt(x)] = algo.getColor2Value();
+          map[parseInt(y, 10)][parseInt(x, 10)] = algo.getColor2Value();
         }
       }
     }
     // Align centered
-    if (algo.align === 1 && width % 2 === 0) {
-      for (y = 0; y < height; y++) {
-        for (x = 0; x < xMax; x++) {
-          map[parseInt(y)][parseInt(x)] = map[parseInt(y)][parseInt(width - x - 1)];
+    if (algo.align === 1) {
+      if (algo.orientation === 0) {
+        for (y = 0; y < yMax; y++) {
+          for (x = 0; x < xMax; x++) {
+            map[parseInt(y, 10)][parseInt(width - x - 1, 10)] = map[parseInt(y, 10)][parseInt(x, 10)];
+          }
+        }
+      } else if (algo.orientation === 1) {
+        for (y = 0; y < yMax; y++) {
+          for (x = 0; x < xMax; x++) {
+            map[parseInt(height - y - 1, 10)][parseInt(x, 10)] = map[parseInt(y, 10)][parseInt(x, 10)];
+          }
+        }
+      } else if (algo.orientation === 2) {
+        for (y = 0; y < yMax; y++) {
+          for (x = 0; x < xMax; x++) {
+            map[parseInt(height - y - 1, 10)][parseInt(x, 10)] = map[parseInt(y, 10)][parseInt(x, 10)];
+            map[parseInt(y, 10)][parseInt(width - x - 1, 10)] = map[parseInt(y, 10)][parseInt(x, 10)];
+            map[parseInt(height - y - 1, 10)][parseInt(width - x - 1, 10)] = map[parseInt(y, 10)][parseInt(x, 10)];
+          }
         }
       }
     }
