@@ -28,7 +28,11 @@
 #include "functionselection.h"
 #include "assignhotkey.h"
 #include "inputpatch.h"
-#include "rgbscript.h"
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+ #include "rgbscript.h"
+#else
+ #include "rgbscriptv4.h"
+#endif
 
 VCMatrixProperties::VCMatrixProperties(VCMatrix* matrix, Doc* doc)
     : QDialog(matrix)
@@ -132,12 +136,10 @@ void VCMatrixProperties::slotAttachFunction()
     FunctionSelection fs(this, m_doc);
     fs.setMultiSelection(false);
     fs.setFilter(Function::RGBMatrixType);
-    fs.disableFilters(Function::SceneType | Function::ChaserType | Function::EFXType | Function::ShowType |
-                      Function::ScriptType | Function::CollectionType | Function::AudioType
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-                      | Function::VideoType
-#endif
-                     );
+    fs.disableFilters(Function::SceneType | Function::ChaserType | Function::EFXType |
+                      Function::ShowType | Function::ScriptType | Function::CollectionType |
+                      Function::AudioType | Function::VideoType);
+
     if (fs.exec() == QDialog::Accepted && fs.selection().size() > 0)
         slotSetFunction(fs.selection().first());
 }
