@@ -44,11 +44,9 @@
 #include "addvcslidermatrix.h"
 #include "vcaudiotriggers.h"
 #include "virtualconsole.h"
-#include "dmxdumpfactory.h"
 #include "vcproperties.h"
 #include "vcspeeddial.h"
 #include "vcsoloframe.h"
-#include "mastertimer.h"
 #include "vcdockarea.h"
 #include "vccuelist.h"
 #include "vcbutton.h"
