@@ -1,13 +1,9 @@
 #!/bin/bash
 
-#############################################################################
-# Engine tests
-#############################################################################
-
 CURRUSER=$(whoami)
 TESTPREFIX=""
 SLEEPCMD=""
-HAS_XSERVER="0"
+RUN_UI_TESTS="0"
 THISCMD=`basename "$0"`
 
 TARGET=${1:-}
@@ -17,16 +13,21 @@ if [ "$TARGET" != "ui" ] && [ "$TARGET" != "qmlui" ]; then
   exit 1
 fi
 
-if [ "$CURRUSER" == "buildbot" ] || [ "$CURRUSER" == "abuild" ]; then
+if [ "$CURRUSER" == "runner" ] \
+    || [ "$CURRUSER" == "buildbot" ] \
+    || [ "$CURRUSER" == "abuild" ]; then
+  echo "Found build environment with CURRUSER='$CURRUSER' and OSTYPE='$OSTYPE'"
   if [[ "$OSTYPE" == "linux-gnu"* ]]; then
     if [ $(which xvfb-run) == "" ]; then
       echo "xvfb-run not found in this system. Please install with: sudo apt-get install xvfb"
       exit
     fi
-    TESTPREFIX="xvfb-run"
-    HAS_XSERVER="1"
+
+    TESTPREFIX="QT_QPA_PLATFORM=minimal xvfb-run --auto-servernum"
+    RUN_UI_TESTS="1"
     # if we're running as build slave, set a sleep time to start/stop xvfb between tests
     SLEEPCMD="sleep 1"
+
   elif [[ "$OSTYPE" == "darwin"* ]]; then
     echo "We're on OSX. Any prefix needed?"
   fi
@@ -39,26 +40,28 @@ else
       XPID=$(pidof Xorg)
     fi
     if [ ${#XPID} -gt 0 ]; then
-      HAS_XSERVER="1"
-    fi
-
-    # no X server ? Let's look for xvfb. This is how Travis is setup
-    if [ -n "$TRAVIS" ]; then
-        HAS_XSERVER="1"
+      RUN_UI_TESTS="1"
     fi
   fi
 fi
 
-# run xmllint on fixture definitions
+#############################################################################
+# Fixture definitions check with xmllint
+#############################################################################
+
 pushd resources/fixtures/scripts
-VALIDATION_ERRORS=$(./check)
+./check
+RET=$?
 popd
-echo $VALIDATION_ERRORS
-if [ "${VALIDATION_ERRORS}" ]; then
+if [ $RET -ne 0 ]; then
     echo "Fixture definitions are not valid. Please fix before commit."
-    exit 1
+    exit $RET
 fi
 
+#############################################################################
+# Engine tests
+#############################################################################
+
 TESTDIR=engine/test
 TESTS=$(find ${TESTDIR} -maxdepth 1 -mindepth 1 -type d)
 for test in ${TESTS}
@@ -74,7 +77,8 @@ do
     $SLEEPCMD
     # Execute the test
     pushd ${TESTDIR}/${test}
-    $TESTPREFIX ./test.sh
+    echo "$TESTPREFIX ./test.sh"
+    eval $TESTPREFIX ./test.sh
     RESULT=${?}
     popd
     if [ ${RESULT} != 0 ]; then
@@ -88,7 +92,7 @@ done
 #############################################################################
 
 # Skip ui in qmlui mode
-if [ "$HAS_XSERVER" -eq "1" ] && [ "$TARGET" != "qmlui" ]; then
+if [ "$RUN_UI_TESTS" -eq "1" ] && [ "$TARGET" != "qmlui" ]; then
 
 TESTDIR=ui/test
 TESTS=$(find ${TESTDIR} -maxdepth 1 -mindepth 1 -type d)
@@ -105,7 +109,7 @@ do
     $SLEEPCMD
     # Execute the test
     pushd ${TESTDIR}/${test}
-    DYLD_FALLBACK_LIBRARY_PATH=../../../engine/src:../../src:$DYLD_FALLBACK_LIBRARY_PATH \
+    eval DYLD_FALLBACK_LIBRARY_PATH=../../../engine/src:../../src:$DYLD_FALLBACK_LIBRARY_PATH \
         LD_LIBRARY_PATH=../../../engine/src:../../src:$LD_LIBRARY_PATH $TESTPREFIX ./${test}_test
     RESULT=${?}
     popd
@@ -123,7 +127,7 @@ fi
 
 $SLEEPCMD
 pushd plugins/enttecwing/test
-$TESTPREFIX ./test.sh
+eval $TESTPREFIX ./test.sh
 RESULT=$?
 if [ $RESULT != 0 ]; then
 	echo "${RESULT} Enttec wing unit tests failed. Please fix before commit."
@@ -140,7 +144,7 @@ if [[ "$OSTYPE" == "darwin"* ]]; then
 else
   $SLEEPCMD
   pushd plugins/velleman/test
-  $TESTPREFIX ./test.sh
+  eval $TESTPREFIX ./test.sh
   RESULT=$?
   if [ $RESULT != 0 ]; then
     echo "Velleman unit test failed ($RESULT). Please fix before commit."
@@ -155,7 +159,7 @@ fi
 
 $SLEEPCMD
 pushd plugins/midi/test
-$TESTPREFIX ./test.sh
+eval $TESTPREFIX ./test.sh
 RESULT=$?
 if [ $RESULT != 0 ]; then
 	echo "${RESULT} MIDI unit tests failed. Please fix before commit."
@@ -169,7 +173,7 @@ popd
 
 $SLEEPCMD
 pushd plugins/artnet/test
-$TESTPREFIX ./test.sh
+eval $TESTPREFIX ./test.sh
 RESULT=$?
 if [ $RESULT != 0 ]; then
 	echo "${RESULT} ArtNet unit tests failed. Please fix before commit."
